@@ -22,17 +22,17 @@ extern GSM_Reply_Function UserReplyFunctions3[];
 
 GSM_Error CheckDCT3Only(void)
 {
-bool found = false;
+	gboolean found = FALSE;
 
 /* Checking if phone is DCT3 */
 #ifdef GSM_ENABLE_NOKIA6110
-if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+	if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 #ifdef GSM_ENABLE_NOKIA7110
-	if (strstr(N7110Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+	if (strstr(N7110Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 #ifdef GSM_ENABLE_NOKIA9210
-	if (strstr(N9210Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = true;
+	if (strstr(N9210Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found = TRUE;
 #endif
 	if (!found) return ERR_NOTSUPPORTED;
 
@@ -45,25 +45,25 @@ if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) != NULL) found =
 	return ERR_NONE;
 }
 
-static void CheckDCT3(void)
+void CheckDCT3(void)
 {
 	GSM_Error error;
 
 	error = CheckDCT3Only();
 	switch (error) {
-	case ERR_NOTSUPPORTED:
-		Print_Error(ERR_NOTSUPPORTED);
-		break;
-	case ERR_OTHERCONNECTIONREQUIRED:
-		printf("Can't do it with current phone protocol\n");
-		GSM_TerminateConnection(gsm);
-		Terminate(3);
-	default:
-		break;
+		case ERR_OTHERCONNECTIONREQUIRED:
+			printf("Can't do it with current phone protocol\n");
+			GSM_TerminateConnection(gsm);
+			Terminate(3);
+		case ERR_NONE:
+			break;
+		default:
+			Print_Error(error);
+			break;
 	}
 }
 
-static bool answer_yes3(const char *text)
+static gboolean answer_yes3(const char *text)
 {
     	int         len;
     	char        ans[99];
@@ -72,8 +72,8 @@ static bool answer_yes3(const char *text)
 		printf("%s (yes/no) ? ",text);
 		len=GetLine(stdin, ans, 99);
 		if (len==-1) Terminate(3);
-		if (strcasecmp(ans, "yes") == 0) return true;
-		if (strcasecmp(ans, "no" ) == 0) return false;
+		if (strcasecmp(ans, "yes") == 0) return TRUE;
+		if (strcasecmp(ans, "no" ) == 0) return FALSE;
 	}
 }
 
@@ -101,7 +101,7 @@ void DCT3GetT9(int argc, char *argv[])
 
 /* "00 01 AE 00" gets some control values */
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	DCT3T9File = fopen("T9", "w");
 	if (DCT3T9File == NULL) return;
@@ -124,7 +124,7 @@ void DCT3VibraTest(int argc, char *argv[])
 				     0xff};	/* Level */
 	GSM_Error error;
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions3;
 
@@ -191,7 +191,7 @@ void DCT3SelfTests(int argc, char *argv[])
 	int		i;
 	GSM_Error error;
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	error=DCT3_EnableSecurity (gsm, 0x01);
 	Print_Error(error);
@@ -203,8 +203,8 @@ void DCT3SelfTests(int argc, char *argv[])
 
 		GSM_Terminate();
 
-		while (!false) {
-			GSM_Init(false);
+		while (!FALSE) {
+			GSM_Init(FALSE);
 			if (error==ERR_NONE) break;
 			GSM_Terminate();
 		}
@@ -266,7 +266,7 @@ void DCT3GetADC(int argc, char *argv[])
 	unsigned char	GetUnit[] = {0x00, 0x01, 0x91,
 				     0x02};		/* Test number */
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions3;
 
@@ -308,7 +308,7 @@ void DCT3DisplayTest(int argc, char *argv[])
 				0x03,          	/* 3=set, 2=clear */
 				0x03};	 	/* test number */
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	if (atoi(argv[2]) != 1 && atoi(argv[2]) != 2) {
 		printf("Give 1 or 2 as test number\n");
@@ -335,7 +335,7 @@ void DCT3netmonitor(int argc, char *argv[])
 	GSM_Error error;
 	char value[100];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT3();
 
@@ -441,7 +441,7 @@ GSM_Error DCT3_ReplyEnableSecurity2(GSM_Protocol_Message msg, GSM_StateMachine *
 	return ERR_NONE;
 }
 
-void DCT3Info(int argc, char *argv[])
+GSM_Error DCT3Info(void)
 {
 	unsigned char 		req[]  	= {0x00, 0x01, 0x8A, 0x00}; 	  /* Get simlock info */
 	unsigned char 		req2[]  = {0x00, 0x01, 0xb4, 0x00, 0x00}; /* Get MSID */
@@ -449,7 +449,8 @@ void DCT3Info(int argc, char *argv[])
 	unsigned char 		req4[]  = {0x00, 0x01, 0xc8, 0x09}; 	  /* Get DSP ROM */
 	GSM_Error error;
 
-        if (CheckDCT3Only()!=ERR_NONE) return;
+	error = CheckDCT3Only();
+	if (error != ERR_NONE) return error;
 
 	gsm->User.UserReplyFunctions=UserReplyFunctions3;
 
@@ -469,6 +470,7 @@ void DCT3Info(int argc, char *argv[])
 
 	error=GSM_WaitFor (gsm, req4, 4, 0x40, 4, ID_User10);
 	Print_Error(error);
+	return ERR_NONE;
 }
 
 static GSM_Error DCT3_ReplyResetTest36(GSM_Protocol_Message msg, GSM_StateMachine *sm)
@@ -482,7 +484,7 @@ void DCT3ResetTest36(int argc, char *argv[])
 	unsigned char req[]  = {0x00, 0x01, 0x65, 0x40, 0x00}; /* Reset test 36 in netmon */
 	GSM_Error error;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
         CheckDCT3();
 
@@ -544,7 +546,7 @@ void DCT3SetPhoneMenus(int argc, char *argv[])
 		0x00, 0x01, 0x6b,
 		0x00, 0x00, 0x00, 0x00 }; /* bytes with Product Profile Setings */
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	error=DCT3_EnableSecurity (gsm, 0x01);
 	Print_Error(error);
@@ -632,7 +634,7 @@ void DCT3GetSecurityCode(int argc, char *argv[])
 #endif
 	GSM_Error error;
 
-	if (CheckDCT3Only()!=ERR_NONE) return;
+	CheckDCT3();
 
 	error=DCT3_EnableSecurity (gsm, 0x01);
 	Print_Error(error);
@@ -677,7 +679,7 @@ void DCT3GetOperatorName(int argc, char *argv[])
 	unsigned char req[] = {0x00,0x01,0x8c,0x00};
 	GSM_Error error;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) == NULL) Print_Error(ERR_NOTSUPPORTED);
 	CheckDCT3();
@@ -707,7 +709,7 @@ void DCT3SetOperatorName(int argc, char *argv[])
 				    0x00,0x00, /* MCC */
 				    0x00};     /* MNC */
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) == NULL) Print_Error(ERR_NOTSUPPORTED);
 	CheckDCT3();
@@ -759,7 +761,7 @@ void DCT3DisplayOutput(int argc, char *argv[])
 			       0x01}; /* 1 = enable, 2 = disable */
 	GSM_Error error;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 
 	if (strstr(N6110Phone.models, gsm->Phone.Data.ModelInfo->model) == NULL) Print_Error(ERR_NOTSUPPORTED);
 	CheckDCT3();
@@ -774,7 +776,7 @@ void DCT3DisplayOutput(int argc, char *argv[])
 	printf("Entering monitor mode...\n\n");
 
 	while (!gshutdown) {
-		GSM_ReadDevice(gsm,true);
+		GSM_ReadDevice(gsm,TRUE);
 		usleep(10000);
 	}
 
