@@ -1,15 +1,15 @@
 /* (c) by Walek */
 
-#include "../../../common/gsmstate.h"
+#include "../../../libgammu/gsmstate.h"
 
 #ifdef GSM_ENABLE_ATGEN
 
 #include <string.h>
 
-#include "../../../common/misc/coding/coding.h"
-#include "../../../common/gsmcomon.h"
-#include "../../../common/service/gsmnet.h"
-#include "../../../common/phone/at/atgen.h"
+#include "../../../libgammu/misc/coding/coding.h"
+#include "../../../libgammu/gsmcomon.h"
+#include "../../../libgammu/service/gsmnet.h"
+#include "../../../libgammu/phone/at/atgen.h"
 #include "../../gammu.h"
 #include "dsiemens.h"
 #include "chiffre.h"
@@ -19,7 +19,7 @@ extern GSM_Error  ATGEN_GetMemoryStatus (GSM_StateMachine *sm, GSM_MemoryStatus
 extern GSM_Error  ATGEN_SetMemory (GSM_StateMachine *sm, GSM_MemoryEntry *pbk);
 extern GSM_Reply_Function UserReplyFunctionsAtS[];
 
-bool 	new_variable;
+gboolean 	new_variable;
 GSM_Error CheckSiemens(void)
 {
 	if (gsm->Phone.Data.Priv.ATGEN.Manufacturer != AT_Siemens) return ERR_NOTSUPPORTED;
@@ -37,12 +37,12 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
    	GSM_NetworkInfo			Network;
 
     	if (Priv->ReplyState!=AT_Reply_OK) return ERR_UNKNOWN;
-    	if (sm->Protocol.Data.AT.EditMode) sm->Protocol.Data.AT.EditMode = false;
+    	if (sm->Protocol.Data.AT.EditMode) sm->Protocol.Data.AT.EditMode = FALSE;
 	if (strstr(GetLineString(msg.Buffer,&Priv->Lines,2),"SSTK")) {
     	    length = strlen(GetLineString(msg.Buffer,&Priv->Lines,2))-7;
     	    DecodeHexBin(buf, GetLineString(msg.Buffer,&Priv->Lines,2)+7,length);
 	    if (buf[0]==0x7f) {
-		new_variable=true;
+		new_variable=TRUE;
 		return ERR_NONE;
 	    }
 	    else return ERR_UNKNOWN;
@@ -55,14 +55,14 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
     	if (buf[3]!=0x26) return ERR_UNKNOWN;
 
 #ifdef DEBUG
-    	dbgprintf ("SAT command: Provide Local Information\nFunction: ");
+    	smprintf(sm, "SAT command: Provide Local Information\nFunction: ");
     	switch (buf[4]) {
-        	case 00: dbgprintf ("Loc Info\n");			break;
-		case 01: dbgprintf ("IMEI\n");				break;
-		case 02: dbgprintf ("Network Measure\n");		break;
-		case 03: dbgprintf ("Date time and timezone\n");	break;
-		case 04: dbgprintf ("Language setting\n");		break;
-		case 05: dbgprintf ("Timing advance\n");		break;
+        	case 00: smprintf(sm, "Loc Info\n");			break;
+		case 01: smprintf(sm, "IMEI\n");				break;
+		case 02: smprintf(sm, "Network Measure\n");		break;
+		case 03: smprintf(sm, "Date time and timezone\n");	break;
+		case 04: smprintf(sm, "Language setting\n");		break;
+		case 05: smprintf(sm, "Timing advance\n");		break;
     	}
 #endif
     	/* Loc Info (MCC, MNC, LAC, Cell ID) */
@@ -90,13 +90,13 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 	        if (result !=0x47) return ERR_NOTSUPPORTED;
 	    }
 #ifdef DEBUG
-	    if (new_variable)	dbgprintf ("New variable Bitmap format\n");
-	    else	 	dbgprintf ("Old variable Bitmap format\n");
+	    if (new_variable)	smprintf(sm, "New variable Bitmap format\n");
+	    else	 	smprintf(sm, "Old variable Bitmap format\n");
 #endif
             GetBufferI(buf+32,&j,&origARFCN,10);
 	/* 10 bit origin ARFCN or first frequency (new variable format) */
 #ifdef DEBUG
-	    dbgprintf("Origin BCCH = %i\n",origARFCN);
+	    smprintf(sm, "Origin BCCH = %i\n",origARFCN);
 #endif
             rep     = buf[31]*8;
 	    if (!new_variable ){
@@ -131,20 +131,20 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 		}
 	    };
 #ifdef DEBUG
-    	dbgprintf("Neighbor BCCH list: ");
-	for (i=1;i<ChNo;i++) dbgprintf ("%d ",frequency[i]);
-	dbgprintf ("\n");
+    	smprintf(sm, "Neighbor BCCH list: ");
+	for (i=1;i<ChNo;i++) smprintf(sm, "%d ",frequency[i]);
+	smprintf(sm, "\n");
 #endif
 	j	= 0;
 	result	= 0;
 	GetBufferI(buf+14,&j,&result,1);
-	if (result) 	MeasureResult.BA_used=true;
-	else		MeasureResult.BA_used=false;
+	if (result) 	MeasureResult.BA_used=TRUE;
+	else		MeasureResult.BA_used=FALSE;
 
 	result	= 0;
 	GetBufferI(buf+14,&j,&result,1);
-	if (result) 	MeasureResult.DTX_used=true;
-	else		MeasureResult.DTX_used=false;
+	if (result) 	MeasureResult.DTX_used=TRUE;
+	else		MeasureResult.DTX_used=FALSE;
 
 	result	= 0;
 	GetBufferI(buf+14,&j,&result,6);
@@ -153,8 +153,8 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
 	j++;	//skip spare bit
 	result	= 0;
 	GetBufferI(buf+14,&j,&result,1);
-	if (result) 	MeasureResult.MeasValid=true;
-	else		MeasureResult.MeasValid=false;
+	if (result) 	MeasureResult.MeasValid=TRUE;
+	else		MeasureResult.MeasValid=FALSE;
 
 	result	= 0;
 	GetBufferI(buf+14,&j,&result,6);
@@ -209,8 +209,8 @@ GSM_Error ATSIEMENS_Reply_GetSAT(GSM_Protocol_Message msg, GSM_StateMachine *sm)
     	}
 #ifdef DEBUG
     	if  (buf[4]==05) {				//Timing Advance
-		if (buf[11]) dbgprintf ("Unknown Timing Advance\n");
-		else dbgprintf ("Timing Advance = %i\n",buf[14] & 0x3f);
+		if (buf[11]) smprintf(sm, "Unknown Timing Advance\n");
+		else smprintf(sm, "Timing Advance = %i\n",buf[14] & 0x3f);
     	}
 #endif
     	return ERR_NONE;
@@ -240,12 +240,12 @@ GSM_Error ATSIEMENS_GetSAT(GSM_StateMachine *sm)
 
     	if (Priv->Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 
-        sprintf(req, "AT^SSTK=?\r");
+        strcpy(req, "AT^SSTK=?\r");
         error = GSM_WaitFor (sm, req, strlen(req), 0x00, 3, ID_User1);
 
     	for (i=0;i<3;i++){
 		len				= strlen(reqSAT[i]);
-		sm->Protocol.Data.AT.EditMode 	= true;
+		sm->Protocol.Data.AT.EditMode 	= TRUE;
         	sprintf(req, "AT^SSTK=%i,1\r",len/2);
         	error = GSM_WaitFor (sm, req, strlen(req), 0x00, 3, ID_User1);
 		sm->Phone.Data.DispatchError	= ERR_TIMEOUT;
@@ -274,11 +274,11 @@ GSM_Error ATSIEMENS_GetNetmon(GSM_StateMachine *sm,int test_no)
 GSM_Error ATSIEMENS_ActivateNetmon (GSM_StateMachine *sm,int netmon_type)
 {
 	GSM_Phone_ATGENData	*Priv = &(sm->Phone.Data.Priv.ATGEN);
-	unsigned char		req[32];
+	char		req[32];
 
 	if (Priv->Manufacturer!=AT_Siemens) return ERR_NOTSUPPORTED;
 
-	sprintf(req, "AT\r");
+	strcpy(req, "AT\r");
 	printf ("Activate Siemens NetMonitor\n");
 	siemens_code (req,req,2);
 
@@ -293,7 +293,7 @@ void ATSIEMENSActivateNetmon(int argc, char *argv[])
 	int 		 netmon_type, pbk_maxlocation;
 	char 		 imsi[15], NetMonCode[32];
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 	if (CheckSiemens()==ERR_NOTSUPPORTED) Print_Error(ERR_NOTSUPPORTED);
 	gsm->User.UserReplyFunctions=UserReplyFunctionsAtS;
 
@@ -316,7 +316,7 @@ void ATSIEMENSActivateNetmon(int argc, char *argv[])
 	    pbk.Entries[0].EntryType = PBK_Number_General;
 	    EncodeUnicode (pbk.Entries[0].Text,NetMonCode,strlen(NetMonCode));
 	    pbk.Entries[1].EntryType = PBK_Text_Name;
-	    sprintf (NetMonCode,"Net Monitor");
+	    strcpy(NetMonCode, "Net Monitor");
 	    EncodeUnicode (pbk.Entries[1].Text,NetMonCode,strlen(NetMonCode));
 	    error = ATGEN_SetMemory (gsm, &pbk);
 	    Print_Error(error);
@@ -329,7 +329,7 @@ void ATSIEMENSActivateNetmon(int argc, char *argv[])
 void ATSIEMENSSATNetmon(int argc, char *argv[])
 {
 	GSM_Error error;
-	GSM_Init(true);
+	GSM_Init(TRUE);
 	if (CheckSiemens()==ERR_NOTSUPPORTED) Print_Error(ERR_NOTSUPPORTED);
 	gsm->User.UserReplyFunctions=UserReplyFunctionsAtS;
 
@@ -345,7 +345,7 @@ void ATSIEMENSNetmonitor(int argc, char *argv[])
 	int test_no;
 	GSM_Error error;
 
-	GSM_Init(true);
+	GSM_Init(TRUE);
 	if (CheckSiemens()==ERR_NOTSUPPORTED) Print_Error(ERR_NOTSUPPORTED);
 	gsm->User.UserReplyFunctions=UserReplyFunctionsAtS;
 
