@@ -54,7 +54,7 @@ void PrintSMSLocation(const GSM_SMSMessage *sms, const GSM_SMSFolders *folders)
  */
 void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 {
-	bool 	found=false,found2=false;
+	gboolean 	found=FALSE,found2=FALSE;
 	int 	i,j,z;
 
 	printf("\"%s\"",DecodeUnicodeConsole(number));
@@ -73,7 +73,7 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 			case PBK_Number_Pager:
 			case PBK_Number_Other:
 				if (mywstrncmp(Info->PhonePhonebook[i]->Entries[j].Text,number,-1)) {
-					found2=true;
+					found2=TRUE;
 					switch (Info->PhonePhonebook[i]->Entries[j].EntryType) {
 					case PBK_Number_Mobile:
 						printf(" (%s", _("mobile"));
@@ -91,10 +91,10 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 						printf(" (%s", _("pager"));
 						break;
 					default:
-						found2=false;
+						found2=FALSE;
 						break;
 					}
-					found=true;
+					found=TRUE;
 				}
 			default:
 				break;
@@ -105,14 +105,14 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 			i++;
 			continue;
 		}
-		found=false;
+		found=FALSE;
 		for (z=0;z<Info->PhonePhonebook[i]->EntriesNum;z++) {
 			switch (Info->PhonePhonebook[i]->Entries[z].EntryType) {
 			case PBK_Text_LastName:
 			case PBK_Text_FirstName:
 				if (!found2) {
 					printf(" (");
-					found2=true;
+					found2=TRUE;
 				} else {
 					if (!found) {
 						printf(", ");
@@ -121,7 +121,7 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 					}
 				}
 				printf("%s",DecodeUnicodeConsole(Info->PhonePhonebook[i]->Entries[z].Text));
-				found=true;
+				found=TRUE;
 				break;
 			default:
 				break;
@@ -132,7 +132,7 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 			case PBK_Text_Name:
 				if (!found2) {
 					printf(" (");
-					found2=true;
+					found2=TRUE;
 				} else {
 					printf(", ");
 				}
@@ -147,7 +147,7 @@ void PrintPhoneNumber(unsigned char *number, const GSM_Backup *Info)
 	}
 }
 
-void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh, const GSM_Backup *Info)
+void DisplaySingleSMSInfo(GSM_SMSMessage sms, gboolean displaytext, gboolean displayudh, const GSM_Backup *Info)
 {
 	GSM_SiemensOTASMSInfo 	SiemensOTA;
 	int			i;
@@ -170,9 +170,9 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 		printf("\n");
 
 		printf(LISTFORMAT "%d\n", _("Reference number"),sms.MessageReference);
-		printf(LISTFORMAT "%s\n", _("Sent"),OSDateTime(sms.DateTime,true));
+		printf(LISTFORMAT "%s\n", _("Sent"),OSDateTime(sms.DateTime,TRUE));
 		printf(LISTFORMAT "\"%s\"\n", _("SMSC number"),DecodeUnicodeConsole(sms.SMSC.Number));
-		printf(LISTFORMAT "%s\n", _("SMSC response"),OSDateTime(sms.SMSCTime,true));
+		printf(LISTFORMAT "%s\n", _("SMSC response"),OSDateTime(sms.SMSCTime,TRUE));
 		printf(LISTFORMAT "%s\n", _("Delivery status"),DecodeUnicodeConsole(sms.Text));
 		printf(LISTFORMAT, _("Details"));
 		if (sms.DeliveryStatus & 0x40) {
@@ -192,7 +192,7 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 			case 0x21: printf(_("SME busy"));					break;
 			case 0x22: printf(_("No response from SME"));				break;
 			case 0x23: printf(_("Service rejected"));				break;
-			case 0x24: printf(_("Quality of service not aviable"));			break;
+			case 0x24: printf(_("Quality of service not available"));		break;
 			case 0x25: printf(_("Error in SME"));					break;
 		        case 0x40: printf(_("Remote procedure error"));				break;
 		        case 0x41: printf(_("Incompatibile destination"));			break;
@@ -217,12 +217,12 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 	case SMS_Deliver:
 		printf("%s\n", _("SMS message"));
 		if (sms.State==SMS_UnSent && sms.Memory==MEM_ME) {
-			printf(LISTFORMAT "%s\n", _("Saved"), OSDateTime(sms.DateTime,true));
+			printf(LISTFORMAT "%s\n", _("Saved"), OSDateTime(sms.DateTime,TRUE));
 		} else {
 			printf(LISTFORMAT "\"%s\"", _("SMSC number"), DecodeUnicodeConsole(sms.SMSC.Number));
 			if (sms.ReplyViaSameSMSC) printf(_(" (set for reply)"));
 			printf("\n");
-			printf(LISTFORMAT "%s\n", _("Sent"), OSDateTime(sms.DateTime,true));
+			printf(LISTFORMAT "%s\n", _("Sent"), OSDateTime(sms.DateTime,TRUE));
 		}
 		/* No break. The only difference for SMS_Deliver and SMS_Submit is,
 		 * that SMS_Deliver contains additional data. We wrote them and then go
@@ -247,22 +247,23 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 		printf(LISTFORMAT, _("Coding"));
 		switch (sms.Coding) {
 			case SMS_Coding_Unicode_No_Compression 	:
-				printf("%s\n", _("Unicode (no compression)"));
+				printf(_("Unicode (no compression)"));
 				break;
 			case SMS_Coding_Unicode_Compression 	:
-				printf("%s\n", _("Unicode (compression)"));
+				printf(_("Unicode (compression)"));
 				break;
 			case SMS_Coding_Default_No_Compression 	:
-				printf("%s\n", _("Default GSM alphabet (no compression)"));
+				printf(_("Default GSM alphabet (no compression)"));
 				break;
 			case SMS_Coding_Default_Compression 	:
-				printf("%s\n", _("Default GSM alphabet (compression)"));
+				printf(_("Default GSM alphabet (compression)"));
 				break;
 			case SMS_Coding_8bit			:
 				/* l10n: 8-bit message coding */
-				printf("%s\n", _("8-bit"));
+				printf(_("8-bit"));
 				break;
 		}
+		printf("\n");
 		if (sms.State==SMS_UnSent && sms.Memory==MEM_ME) {
 		} else {
 			printf(LISTFORMAT, ngettext("Remote number", "Remote numbers", sms.OtherNumbersNum + 1));
@@ -275,11 +276,12 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 		}
 		printf(LISTFORMAT, _("Status"));
 		switch (sms.State) {
-			case SMS_Sent	:	printf("%s\n", _("Sent"));	break;
-			case SMS_Read	:	printf("%s\n", _("Read"));	break;
-			case SMS_UnRead	:	printf("%s\n", _("UnRead"));	break;
-			case SMS_UnSent	:	printf("%s\n", _("UnSent"));	break;
+			case SMS_Sent	:	printf(_("Sent"));	break;
+			case SMS_Read	:	printf(_("Read"));	break;
+			case SMS_UnRead	:	printf(_("UnRead"));	break;
+			case SMS_UnSent	:	printf(_("UnSent"));	break;
 		}
+		printf("\n");
 		if (sms.UDH.Type != UDH_NoUDH) {
 			printf(LISTFORMAT, _("User Data Header"));
 			switch (sms.UDH.Type) {
@@ -340,11 +342,11 @@ void DisplaySingleSMSInfo(GSM_SMSMessage sms, bool displaytext, bool displayudh,
 	}
 }
 
-void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, const GSM_Backup *Info, GSM_StateMachine *sm)
+void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, gboolean eachsms, gboolean ems, const GSM_Backup *Info, GSM_StateMachine *sm)
 {
 	GSM_SiemensOTASMSInfo 	SiemensOTA;
 	GSM_MultiPartSMSInfo	SMSInfo;
-	bool			RetVal,udhinfo=true;
+	gboolean			RetVal,udhinfo=TRUE;
 	int			j,i;
 	size_t Pos;
 	GSM_MemoryEntry		pbk;
@@ -354,10 +356,10 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, cons
 	RetVal = GSM_DecodeMultiPartSMS(GSM_GetGlobalDebug(), &SMSInfo,sms,ems);
 
 	if (eachsms) {
-		if (GSM_DecodeSiemensOTASMS(GSM_GetGlobalDebug(), &SiemensOTA,&sms->SMS[0])) udhinfo = false;
-		if (sms->SMS[0].UDH.Type != UDH_NoUDH && sms->SMS[0].UDH.AllParts == sms->Number) udhinfo = false;
+		if (GSM_DecodeSiemensOTASMS(GSM_GetGlobalDebug(), &SiemensOTA,&sms->SMS[0])) udhinfo = FALSE;
+		if (sms->SMS[0].UDH.Type != UDH_NoUDH && sms->SMS[0].UDH.AllParts == sms->Number) udhinfo = FALSE;
 		if (RetVal && !udhinfo) {
-			DisplaySingleSMSInfo(sms->SMS[0],false,false,Info);
+			DisplaySingleSMSInfo(sms->SMS[0],FALSE,FALSE,Info);
 			printf("\n");
 		} else {
 			for (j=0;j<sms->Number;j++) {
@@ -367,7 +369,7 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, cons
 		}
 	} else {
 		for (j=0;j<sms->Number;j++) {
-			DisplaySingleSMSInfo(sms->SMS[j],!RetVal,true,Info);
+			DisplaySingleSMSInfo(sms->SMS[j],!RetVal,TRUE,Info);
 			printf("\n");
 		}
 	}
@@ -425,7 +427,7 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, cons
 			GSM_PrintBitmap(stdout,&SMSInfo.Entries[i].Bitmap->Bitmap[0]);
 			break;
 		case SMS_NokiaPictureImageLong:
-			printf("%s\n", _("Picture Image"));
+			printf("%s\n", _("Picture"));
 			if (UnicodeLength(SMSInfo.Entries[i].Bitmap->Bitmap[0].Text) != 0)
 				printf(LISTFORMAT "\"%s\"\n\n", _("Text"),DecodeUnicodeConsole(SMSInfo.Entries[i].Bitmap->Bitmap[0].Text));
 			GSM_PrintBitmap(stdout,&SMSInfo.Entries[i].Bitmap->Bitmap[0]);
@@ -440,7 +442,8 @@ void DisplayMultiSMSInfo (GSM_MultiSMSMessage *sms, bool eachsms, bool ems, cons
 		case SMS_ConcatenatedAutoTextLong16bit:
 		case SMS_NokiaVCARD21Long:
 		case SMS_NokiaVCALENDAR10Long:
-			printf("%s\n",DecodeUnicodeConsole(SMSInfo.Entries[i].Buffer));
+			if (SMSInfo.Entries[i].Buffer == NULL) printf("\n");
+			else printf("%s\n",DecodeUnicodeConsole(SMSInfo.Entries[i].Buffer));
 			break;
 		case SMS_EMSFixedBitmap:
 		case SMS_EMSVariableBitmap:
@@ -504,7 +507,7 @@ void DisplaySMSFrame(GSM_SMSMessage *SMS, GSM_StateMachine *sm)
 	unsigned char		req[1000], buffer[1000], hexreq[1000];
         unsigned char           hexmsg[1000], hexudh[1000];
 
-	error=PHONE_EncodeSMSFrame(sm,SMS,buffer,PHONE_SMSSubmit,&length,true);
+	error=PHONE_EncodeSMSFrame(sm,SMS,buffer,PHONE_SMSSubmit,&length,TRUE);
 	if (error != ERR_NONE) {
 		printf("%s\n", _("Error"));
 		exit(-1);
