@@ -109,6 +109,10 @@ GSM_FeatureName AllFeatureNames[] = {
 	{"PBKFAVORITEMESSAGE", F_PBKFAVORITEMESSAGE},
 	{"PBKNOPOSTAL", F_PBKNOPOSTAL},
 	{"PBK_ENCODENUMBER", F_PBK_ENCODENUMBER},
+	{"NO_CLIP", F_NO_CLIP},
+	{"ENCODED_USSD", F_ENCODED_USSD},
+	{"USE_SMSTEXTMODE", F_USE_SMSTEXTMODE},
+	{"CPIN_NO_OK", F_CPIN_NO_OK},
 	{"", 0},
 };
 
@@ -196,6 +200,7 @@ GSM_PhoneModel allmodels[] = {
 	{"3310" ,"NHM-5" ,"",           {F_NOWAP,F_NOCALLER,F_RING_SM,F_CAL33,F_POWER_BATT,F_PROFILES33,F_NOCALLINFO,F_NODTMF,0}},
 	{"3330" ,"NHM-6" ,"",           {F_NOCALLER,F_RING_SM,F_CAL33,F_PROFILES33,F_NOPICTUREUNI,F_NOCALLINFO,F_NODTMF,0}},
 	{"3390" ,"NPB-1" ,"",           {F_NOWAP,F_NOCALLER,F_RING_SM,F_CAL33,F_PROFILES33,F_NOPICTUREUNI,F_NOCALLINFO,F_NODTMF,0}},
+	{"3390b" ,"NPB-1RB" ,"",	{F_NOWAP,F_NOCALLER,F_RING_SM,F_CAL33,F_PROFILES33,F_NOPICTUREUNI,F_NOCALLINFO,F_NODTMF,0}},
 	{"3410" ,"NHM-2" ,"",           {F_RING_SM,F_CAL33,F_PROFILES33,F_NOCALLINFO,F_NODTMF,0}},
 	{"3610" ,"NAM-1" ,"",           {F_NOCALLER,F_RING_SM,F_CAL33,F_POWER_BATT,F_PROFILES33,F_NOCALLINFO,F_NODTMF,0}},/* guess */
 	{"5510" ,"NPM-5" ,"",           {F_NOCALLER,F_PROFILES33,F_NOPICTUREUNI,F_RING_SM,0}},
@@ -248,9 +253,11 @@ GSM_PhoneModel allmodels[] = {
 	{"1110i","RM-93" ,"Nokia 1110i",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"1112", "RH-93" ,"Nokia 1112", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"1200", "RH-99" ,"Nokia 1200", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"1209", "RH-105","Nokia 1209", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2125i","RH-71" ,"Nokia 2125i",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"1600", "RH-64" ,"Nokia 1600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"1680", "RM-394","Nokia 1680",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
+	{"1681c","RH-118","Nokia 1681c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"2600", "RH-340","Nokia 2600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2600", "RM-340","Nokia 2600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"2610", "RH-86", "Nokia 2610",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
@@ -260,18 +267,20 @@ GSM_PhoneModel allmodels[] = {
 	{"2680", "RM-392","Nokia 2680", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2760", "RM-258","Nokia 2760",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"3109c","RM-274","Nokia 3109c",{F_SERIES40_30,F_FILES2,F_TODO66,F_PBKUSER,F_PBKTONEGAL,F_NOTES,F_SMS_FILES,F_CHAT,F_SYNCML,F_6230iCALLER,0}},/* guess */
-	{"3110c","RM-237","Nokia 3110c",{F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
+	{"3110c","RM-237","Nokia 3110c",{F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_SMS_FILES,0}},/* guess */
 	{"3220" ,"RH-37" ,"",           {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_SYNCML,F_FILES2,F_3220_MMS,0}},
 	{"3220" ,"RH-49" ,"",           {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_SYNCML,F_FILES2,F_3220_MMS,0}},
 	{"3500" ,"RM-272","Nokia 3500", {F_SERIES40_30,F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},/* guess */
 	{"5000", "RM-362","Nokia 5000", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"5100" ,"NPM-6" ,"Nokia 5100", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
+	{"5130" ,"RM-495","Nokia 5130", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"5100" ,"NPM-6U","Nokia 5100", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
 	{"5100" ,"NPM-6X","Nokia 5100", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
 	{"5140" ,"NPL-4" ,"Nokia 5140", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKUSER,F_WAPMMSPROXY,F_CHAT, F_SYNCML,0}},
 	{"5140" ,"NPL-5" ,"Nokia 5140", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKUSER,F_WAPMMSPROXY,F_CHAT, F_SYNCML,0}},
 	{"5140i","RM-104","Nokia 5140i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKUSER,F_WAPMMSPROXY,F_CHAT, F_SYNCML,0}},
 	{"5200" ,"RM-174","Nokia 5200", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
+	{"5220" ,"RM-411","Nokia 5220", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"5300" ,"RM-146","Nokia 5300", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},
 	{"5310" ,"RM-303","Nokia 5310", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"6020" ,"RM-30" ,"Nokia 6020", {F_VOICETAGS, F_FILES2, F_CHAT, F_WAPMMSPROXY, F_TODO66, F_PBKTONEGAL, F_NOTES,0}},/* guess */
@@ -325,6 +334,7 @@ GSM_PhoneModel allmodels[] = {
 	{"6822" ,"RM-69" ,"Nokia 6822", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"7200" ,"RH-23" ,"Nokia 7200", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,0}},/* guess */
 	{"7210" ,"NHL-4" ,"Nokia 7210", {F_PBKTONEGAL,F_TODO66,F_RADIO,0}},
+	{"7210s","RM-436","Nokia 7210s",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"7250" ,"NHL-4J","Nokia 7250", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKIMG,F_SYNCML,0}},
 	{"7250i","NHL-4JX","Nokia 7250i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKIMG,F_SYNCML,0}},
 	{"7260" ,"RM-17" ,"Nokia 7260", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
@@ -333,6 +343,7 @@ GSM_PhoneModel allmodels[] = {
 	{"7360" ,"RM-127","Nokia 7360", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"7370" ,"RM-70" ,"Nokia 7370", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"7373" ,"RM-209","Nokia 7373", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
+	{"7500" ,"RM-249","Nokia 7500", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"7600", "NMM-3", "Nokia 7600", {F_TODO66,0}},
 	{"7900" ,"RM-264","Nokia 7900", {F_SERIES40_30,F_FILES2,F_TODO66,F_NOTES,F_SMS_FILES,0}},
 	{"8310" ,"NHM-7" ,"Nokia 8310", {F_CAL62,F_NOMIDI,F_RADIO,F_NOFILESYSTEM,F_NOMMS,F_VOICETAGS,0}},
@@ -394,6 +405,9 @@ GSM_PhoneModel allmodels[] = {
 	{"V200" ,	  "SGH-V200" ,    "",				   {0}},
 	{"X461",	  "SGH-X461" ,    "",				   {0}},
 	{"D357",	  "SGH-D357" ,	  "",				   {F_EXTRA_PBK_FIELD, 0}},
+	{"J750",	  "SGH-J750" ,	  "",				   {F_NO_ATOBEX, 0}},
+	{"J700",	  "SGH-J700" ,	  "",				   {F_NO_ATOBEX, 0}},
+	{"J700",	  "SAMSUNG SGH-J700" , "",			   {F_NO_ATOBEX, 0}},
 
 	/* Ericsson/Sony Ericsson */
 	{"T28s",	"1101101-BVT28s","",				   {F_OBEX, 0}},
@@ -553,12 +567,12 @@ GSM_PhoneModel allmodels[] = {
 	{"J210i",	"AAB-1021062-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"J210c",	"AAB-1021062-CN" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K300i/K300c",	"AAB-1021071-BV" ,"K300i",			   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"K750i/K750c",	"AAB-1022011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"D750i/K758c",	"AAB-1022012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"W800i/W800c",	"AAB-1022013-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"W700i/W700c",	"AAB-1022014-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"Z550i/Z550c",	"AAB-1022015-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
-	{"Z558i/Z558c",	"AAB-1022016-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
+	{"K750i/K750c",	"AAB-1022011-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
+	{"D750i/K758c",	"AAB-1022012-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
+	{"W800i/W800c",	"AAB-1022013-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
+	{"W700i/W700c",	"AAB-1022014-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
+	{"Z550i/Z550c",	"AAB-1022015-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
+	{"Z558i/Z558c",	"AAB-1022016-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, F_NO_CLIP, 0}},
 	{"W550i/W550c",	"AAB-1022021-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"Z530i/Z530c",	"AAB-1022031-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
 	{"K510i/K510c",	"AAB-1022041-BV" ,"",				   {F_OBEX, F_SUBMIT_SIM_ONLY, 0}},
@@ -737,10 +751,12 @@ GSM_PhoneModel allmodels[] = {
 	{"V3",		"V3 Razr", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"V8",		"V8", "",					   {F_PBK_UNICODE, 0}},
 	{"L6",		"L6", "",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
+	{"PEBL U6",	"PEBL U6",	"",				   {F_NO_ATOBEX, F_PBK_UNICODE, 0}},
 	{"Serias E",	"Serias E",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"E815m",	"E815m",	"",				   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
 	{"V635",	"V635",	"",					   {F_OBEX, F_IRMC_LEVEL_2, F_MODE22, F_PBK_UNICODE, 0}},
-	{"L7",		"L7", "",					   {F_CKPD_NO_UNICODE, 0}},
+	{"L7",		"L7", "",					   {F_NO_ATOBEX, F_CKPD_NO_UNICODE, F_USE_SMSTEXTMODE, 0}},
+	{"K1",		"K1", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, F_USE_SMSTEXTMODE, 0}},
 	{"K1v",		"K1v", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, 0}},
 	{"Z6c",		"Z6c", "",					   {F_NO_ATOBEX, F_PBK_UNICODE, 0}},
 	{"V180",	"V180", "",					   {F_NO_ATOBEX, 0}},
@@ -764,7 +780,10 @@ GSM_PhoneModel allmodels[] = {
 
 	/* Huawei */
 	{"E220",	"E220",		"",		{0}},
-	{"E160",	"E160",		"",		{F_SMS_LOCATION_0, 0}},
+	{"E160",	"E160",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
+	{"E162",	"E162",		"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
+	{"E160G",	"E160G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
+	{"E162G",	"E162G",	"",		{F_SMS_LOCATION_0, F_ENCODED_USSD, 0}},
 
 #endif
 #if defined(GSM_ENABLE_ATGEN) || defined(GSM_ENABLE_ALCATEL)
@@ -802,33 +821,33 @@ GSM_PhoneModel *GetModelData(GSM_StateMachine *s, const char *model, const char
 	return (&allmodels[i]);
 }
 
-bool GSM_IsPhoneFeatureAvailable(GSM_PhoneModel *model, GSM_Feature feature)
+gboolean GSM_IsPhoneFeatureAvailable(GSM_PhoneModel *model, GSM_Feature feature)
 {
 	int	i	= 0;
 
 	while (model->features[i] != 0) {
 		if (model->features[i] == feature) {
-			return true;
+			return TRUE;
 		}
 		i++;
 	}
-	return false;
+	return FALSE;
 }
 
-bool GSM_AddPhoneFeature(GSM_PhoneModel *model, GSM_Feature feature)
+gboolean GSM_AddPhoneFeature(GSM_PhoneModel *model, GSM_Feature feature)
 {
 	int	i	= 0;
 
 	while (model->features[i] != 0) {
 		if (model->features[i] == feature) {
-			return true;
+			return TRUE;
 		}
 		i++;
 	}
-	if (i == GSM_MAX_PHONE_FEATURES) return false;
+	if (i == GSM_MAX_PHONE_FEATURES) return FALSE;
 	model->features[i++] = feature;
 	model->features[i++] = 0;
-	return true;
+	return TRUE;
 }
 
 /* How should editor hadle tabs in this file? Add editor commands here.
