@@ -109,7 +109,7 @@ GSM_Error ATGEN_ReplyGetSMSMemories(GSM_Protocol_Message msg, GSM_StateMachine *
 			if (strstr(msg.Buffer, "\"MT\"") != NULL && strstr(msg.Buffer, "\"OM\"") != NULL) {
 				s->Phone.Data.Priv.ATGEN.PhoneSMSMemory = AT_AVAILABLE;
 				s->Phone.Data.Priv.ATGEN.PhoneSaveSMS = AT_AVAILABLE;
-				s->Phone.Data.Priv.ATGEN.MotorolaSMS = true;
+				s->Phone.Data.Priv.ATGEN.MotorolaSMS = TRUE;
 			}
 
 		}
@@ -138,7 +138,7 @@ GSM_Error ATGEN_GetSMSMemories(GSM_StateMachine *s)
 	GSM_Phone_ATGENData *Priv = &s->Phone.Data.Priv.ATGEN;
 
 	smprintf(s, "Getting available SMS memories\n");
-	ATGEN_WaitFor(s, "AT+CPMS=?\r", 20, 0x00, 4, ID_GetSMSMemories);
+	ATGEN_WaitFor(s, "AT+CPMS=?\r", 10, 0x00, 4, ID_GetSMSMemories);
 
 	if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SMS_SM)) {
 		smprintf(s, "Forcing support for SM storage!\n");
@@ -155,7 +155,7 @@ GSM_Error ATGEN_GetSMSMemories(GSM_StateMachine *s)
 	return error;
 }
 
-GSM_Error ATGEN_SetSMSMemory(GSM_StateMachine *s, bool SIM, bool for_write, bool outbox)
+GSM_Error ATGEN_SetSMSMemory(GSM_StateMachine *s, gboolean SIM, gboolean for_write, gboolean outbox)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	char 			req[] = "AT+CPMS=\"XX\",\"XX\"\r";
@@ -245,11 +245,14 @@ GSM_Error ATGEN_GetSMSMode(GSM_StateMachine *s)
 
 	if (Priv->SMSMode != 0) return ERR_NONE;
 
-	smprintf(s, "Trying SMS PDU mode\n");
-	ATGEN_WaitFor(s, "AT+CMGF=0\r", 10, 0x00, 9, ID_GetSMSMode);
-	if (error==ERR_NONE) {
-		Priv->SMSMode = SMS_AT_PDU;
-		return ERR_NONE;
+	/* Prefer PDU mode for most phones */
+	if (!GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_USE_SMSTEXTMODE)) {
+		smprintf(s, "Trying SMS PDU mode\n");
+		ATGEN_WaitFor(s, "AT+CMGF=0\r", 10, 0x00, 9, ID_GetSMSMode);
+		if (error==ERR_NONE) {
+			Priv->SMSMode = SMS_AT_PDU;
+			return ERR_NONE;
+		}
 	}
 
 	smprintf(s, "Trying SMS text mode\n");
@@ -259,7 +262,7 @@ GSM_Error ATGEN_GetSMSMode(GSM_StateMachine *s)
 		smprintf(s, "Enabling displaying all parameters in text mode\n");
 		ATGEN_WaitFor(s, "AT+CSDH=1\r", 10, 0x00, 3, ID_GetSMSMode);
 		if (error == ERR_NONE) {
-			Priv->SMSTextDetails = true;
+			Priv->SMSTextDetails = TRUE;
 		} else {
 			error = ERR_NONE;
 		}
@@ -268,18 +271,18 @@ GSM_Error ATGEN_GetSMSMode(GSM_StateMachine *s)
 	return error;
 }
 
-GSM_Error ATGEN_GetSMSLocation(GSM_StateMachine *s, GSM_SMSMessage *sms, unsigned char *folderid, int *location, bool for_write)
+GSM_Error ATGEN_GetSMSLocation(GSM_StateMachine *s, GSM_SMSMessage *sms, unsigned char *folderid, int *location, gboolean for_write)
 {
 	GSM_Phone_ATGENData 	*Priv = &s->Phone.Data.Priv.ATGEN;
 	int			ifolderid, maxfolder;
 	GSM_Error		error;
 
 	if (Priv->PhoneSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, false, for_write, (sms->Folder % 2) == 0);
+		error = ATGEN_SetSMSMemory(s, FALSE, for_write, (sms->Folder % 2) == 0);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, true, for_write, (sms->Folder % 2) == 0);
+		error = ATGEN_SetSMSMemory(s, TRUE, for_write, (sms->Folder % 2) == 0);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 
@@ -330,10 +333,10 @@ GSM_Error ATGEN_GetSMSLocation(GSM_StateMachine *s, GSM_SMSMessage *sms, unsigne
 	if (Priv->SIMSMSMemory == AT_AVAILABLE &&
 			*folderid == 1) {
 		sms->Memory = MEM_SM;
-		return ATGEN_SetSMSMemory(s, true, for_write, (sms->Folder % 2) == 0);
+		return ATGEN_SetSMSMemory(s, TRUE, for_write, (sms->Folder % 2) == 0);
 	} else {
 		sms->Memory = MEM_ME;
-		return ATGEN_SetSMSMemory(s, false, for_write, (sms->Folder % 2) == 0);
+		return ATGEN_SetSMSMemory(s, FALSE, for_write, (sms->Folder % 2) == 0);
 	}
 }
 
@@ -358,10 +361,10 @@ void ATGEN_SetSMSLocation(GSM_StateMachine *s, GSM_SMSMessage *sms, unsigned cha
 GSM_Error ATGEN_DecodePDUMessage(GSM_StateMachine *s, const char *PDU, const int state)
 {
 	GSM_Phone_ATGENData 	*Priv 	= &s->Phone.Data.Priv.ATGEN;
+	GSM_Error error;
 	GSM_SMSMessage		*sms	= &s->Phone.Data.GetSMSMessage->SMS[0];
-	int 			current = 0, current2, i, length;
-	int			datalength;
-	unsigned char 		buffer[300],smsframe[800];
+	unsigned char 		buffer[300];
+	size_t			parse_len, length;
 
 	length = strlen(PDU);
 	if (!DecodeHexBin (
@@ -387,202 +390,40 @@ GSM_Error ATGEN_DecodePDUMessage(GSM_StateMachine *s, const char *PDU, const int
 			break;
 	}
 	length /= 2; /* We decoded hex -> binary */
-	/* Siemens M20 */
-	if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_M20SMS)) {
-		/* we check for the most often visible */
-		if (buffer[1]!=NUMBER_UNKNOWN_NUMBERING_PLAN_ISDN && buffer[1]!=NUMBER_INTERNATIONAL_NUMBERING_PLAN_ISDN &&
-		    buffer[1]!=NUMBER_ALPHANUMERIC_NUMBERING_PLAN_UNKNOWN) {
-			/* Seems to be Delivery Report */
-			smprintf(s, "SMS type - status report (M20 style)\n");
+	error = GSM_DecodePDUFrame(&(s->di), sms,  buffer, length, &parse_len, TRUE);
+	if (error != ERR_NONE) return error;
+	if (parse_len != length) {
+		smprintf(s, "Did not parse all PDU data (%d, %d)!\n", (int)parse_len, (int)length);
+		return ERR_UNKNOWN;
+	}
+
+	switch (sms->PDU) {
+		case SMS_Deliver:
+			/* @bug Broken when MEM_SM is not available */
+			if (Priv->SMSMemory == MEM_SM) {
+				sms->Folder = 1; /*INBOX SIM*/
+			} else {
+				sms->Folder = 3; /*INBOX ME*/
+			}
+			sms->InboxFolder = TRUE;
+			break;
+		case SMS_Submit:
+			/* @bug Broken when MEM_SM is not available */
+			if (Priv->SMSMemory == MEM_SM) {
+				sms->Folder = 2; /*OUTBOX SIM*/
+				smprintf(s, "Outbox SIM\n");
+			} else {
+				sms->Folder = 4; /*OUTBOX ME*/
+			}
+			sms->InboxFolder = FALSE;
+			break;
+		case SMS_Status_Report:
 			sms->PDU 	 = SMS_Status_Report;
 			sms->Folder 	 = 1;	/*INBOX SIM*/
-			sms->InboxFolder = true;
-
-			smsframe[12]=buffer[current++];
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[PHONE_SMSStatusReport.TPMR]=buffer[current++];
-			if (current >= length) return ERR_CORRUPTED;
-			current2=((buffer[current])+1)/2+1;
-			for (i = 0; i < current2 + 1; i++) {
-				smsframe[PHONE_SMSStatusReport.Number+i]=buffer[current++];
-				if (current >= length) return ERR_CORRUPTED;
-			}
-			for (i = 0; i < 7; i++) {
-				smsframe[PHONE_SMSStatusReport.DateTime+i]=buffer[current++];
-				if (current >= length) return ERR_CORRUPTED;
-			}
-			smsframe[0] = 0;
-			for (i = 0; i < 7; i++) {
-				smsframe[PHONE_SMSStatusReport.SMSCTime+i]=buffer[current++];
-				if (current >= length) return ERR_CORRUPTED;
-			}
-			smsframe[PHONE_SMSStatusReport.TPStatus]=buffer[current];
-			GSM_DecodeSMSFrame(&(s->di), sms,smsframe,PHONE_SMSStatusReport);
-			return ERR_NONE;
-		}
+			sms->InboxFolder = TRUE;
+			break;
 	}
-	/* We use locations from SMS layouts like in ../phone2.c(h) */
-	for(i = 0; i < buffer[0] + 1; i++) {
-		smsframe[i]=buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-	}
-	smsframe[12]=buffer[current++];
-	if (current >= length) return ERR_CORRUPTED;
-	/* See GSM 03.40 section 9.2.3.1 */
-	switch (smsframe[12] & 0x03) {
-	case 0x00:
-		smprintf(s, "SMS type - deliver\n");
-		sms->PDU 	 = SMS_Deliver;
-		/* @bug Broken when MEM_SM is not available */
-		if (Priv->SMSMemory == MEM_SM) {
-			sms->Folder = 1; /*INBOX SIM*/
-		} else {
-			sms->Folder = 3; /*INBOX ME*/
-		}
-		sms->InboxFolder = true;
-		current2 = buffer[current];
-		if (current2 % 2) current2++;
-		current2 = current2 / 2 + 1;
-		if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_M20SMS)) {
-			if (buffer[current+1]==NUMBER_ALPHANUMERIC_NUMBERING_PLAN_UNKNOWN) {
-				smprintf(s, "Trying to read alphanumeric number\n");
-				for (i = 0; i < 4; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSDeliver.Number+i]=buffer[current++];
-				}
-				current+=6;
-				for (i = 0; i < current2 - 3; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSDeliver.Number+i+4]=buffer[current++];
-				}
-			} else {
-				for (i = 0; i < current2 + 1; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSDeliver.Number+i]=buffer[current++];
-				}
-			}
-		} else {
-			for (i = 0; i < current2 + 1; i++) {
-				if (current >= length) return ERR_CORRUPTED;
-				smsframe[PHONE_SMSDeliver.Number+i]=buffer[current++];
-			}
-		}
-		smsframe[PHONE_SMSDeliver.TPPID] = buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-		smsframe[PHONE_SMSDeliver.TPDCS] = buffer[current++];
-		for (i = 0; i < 7; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[PHONE_SMSDeliver.DateTime+i]=buffer[current++];
-		}
-		smsframe[PHONE_SMSDeliver.TPUDL] = buffer[current++];
-		if (current > length) return ERR_CORRUPTED;
-		datalength = smsframe[PHONE_SMSDeliver.TPUDL];
-		if (GSM_GetMessageCoding(&(s->di), smsframe[PHONE_SMSDeliver.TPDCS]) == SMS_Coding_Default_No_Compression) {
-			datalength = (datalength * 7) / 8;
-			if ((smsframe[PHONE_SMSDeliver.TPUDL] * 7) % 8 != 0) {
-				datalength++;
-			}
-		}
-		for (i = 0; i < datalength; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[i+PHONE_SMSDeliver.Text]=buffer[current++];
-		}
-		if (current != length) {
-			smprintf(s, "Did not reach message end! (current = %d, length = %d)\n", current, length);
-		}
-		return GSM_DecodeSMSFrame(&(s->di), sms,smsframe,PHONE_SMSDeliver);
-	case 0x01:
-		smprintf(s, "SMS type - submit\n");
-		sms->PDU 	 = SMS_Submit;
-		/* @bug Broken when MEM_SM is not available */
-		if (Priv->SMSMemory == MEM_SM) {
-			sms->Folder = 2; /*OUTBOX SIM*/
-			smprintf(s, "Outbox SIM\n");
-		} else {
-			sms->Folder = 4; /*OUTBOX ME*/
-		}
-		sms->InboxFolder = false;
-		if (current >= length) return ERR_CORRUPTED;
-		smsframe[PHONE_SMSSubmit.TPMR] = buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-		current2 = buffer[current];
-		if (current2 % 2) current2++;
-		current2 = current2 / 2 + 1;
-		if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_M20SMS)) {
-			if (buffer[current+1]==NUMBER_ALPHANUMERIC_NUMBERING_PLAN_UNKNOWN) {
-				smprintf(s, "Trying to read alphanumeric number\n");
-				for (i = 0; i < 4; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSSubmit.Number+i]=buffer[current++];
-				}
-				current+=6;
-				if (current >= length) return ERR_CORRUPTED;
-				for (i = 0; i < current2 - 3; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSSubmit.Number+i+4]=buffer[current++];
-				}
-			} else {
-				for (i = 0; i < current2 + 1; i++) {
-					if (current >= length) return ERR_CORRUPTED;
-					smsframe[PHONE_SMSSubmit.Number+i]=buffer[current++];
-				}
-			}
-		} else {
-			for (i = 0; i < current2 + 1; i++) {
-				if (current >= length) return ERR_CORRUPTED;
-				smsframe[PHONE_SMSSubmit.Number+i]=buffer[current++];
-			}
-		}
-		smsframe[PHONE_SMSSubmit.TPPID] = buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-		smsframe[PHONE_SMSSubmit.TPDCS] = buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-		/* See GSM 03.40 9.2.3.3 - TPVP can not exist in frame */
-		if ((smsframe[12] & 0x18)!=0) current++; /* TPVP is ignored now */
-		if (current > length) return ERR_CORRUPTED;
-		smsframe[PHONE_SMSSubmit.TPUDL] = buffer[current++];
-		datalength = smsframe[PHONE_SMSSubmit.TPUDL];
-		if (GSM_GetMessageCoding(&(s->di), smsframe[PHONE_SMSSubmit.TPDCS]) == SMS_Coding_Default_No_Compression) {
-			datalength = (datalength * 7) / 8;
-			if ((smsframe[PHONE_SMSSubmit.TPUDL] * 7) % 8 != 0) {
-				datalength++;
-			}
-		}
-		for (i = 0; i < datalength; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[i+PHONE_SMSSubmit.Text]=buffer[current++];
-		}
-		if (current != length) {
-			smprintf(s, "Did not reach message end! (current = %d, length = %d)\n", current, length);
-		}
-		return GSM_DecodeSMSFrame(&(s->di), sms,smsframe,PHONE_SMSSubmit);
-	case 0x02:
-		smprintf(s, "SMS type - status report\n");
-		sms->PDU 	 = SMS_Status_Report;
-		sms->Folder 	 = 1;	/*INBOX SIM*/
-		sms->InboxFolder = true;
-		smprintf(s, "TPMR is %d\n",buffer[current]);
-		smsframe[PHONE_SMSStatusReport.TPMR] = buffer[current++];
-		if (current >= length) return ERR_CORRUPTED;
-		current2=((buffer[current])+1)/2+1;
-		for (i = 0; i < current2 + 1; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[PHONE_SMSStatusReport.Number+i]=buffer[current++];
-		}
-		for (i = 0; i < 7; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[PHONE_SMSStatusReport.DateTime+i]=buffer[current++];
-		}
-		for (i = 0; i < 7; i++) {
-			if (current >= length) return ERR_CORRUPTED;
-			smsframe[PHONE_SMSStatusReport.SMSCTime+i]=buffer[current++];
-		}
-		smsframe[PHONE_SMSStatusReport.TPStatus]=buffer[current];
-		return GSM_DecodeSMSFrame(&(s->di), sms,smsframe,PHONE_SMSStatusReport);
-	case 0x03:
-		smprintf(s, "SMS type - reserved, don't know what to do\n");
-	}
-	return ERR_UNKNOWN;
+	return ERR_NONE;
 }
 
 GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s)
@@ -590,8 +431,10 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 	GSM_Phone_ATGENData 	*Priv 	= &s->Phone.Data.Priv.ATGEN;
 	GSM_SMSMessage		*sms	= &s->Phone.Data.GetSMSMessage->SMS[0];
 	int 			current = 0, i;
+	size_t			length;
 	unsigned char 		buffer[300];
 	unsigned char		firstbyte, TPDCS, TPUDL, TPStatus;
+	const char		*line;
 	GSM_Error		error=ERR_UNKNOWN;
 
 	switch (Priv->ReplyState) {
@@ -612,8 +455,9 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 		case SMS_AT_TXT:
 			error = ATGEN_ParseReply(s,
 					GetLineString(msg.Buffer, &Priv->Lines, 2),
-					"+CMGL: @i, @r, @p, @0",
-					&current, buffer, sizeof(buffer), sms->Number, sizeof(sms->Number));
+					"+CMGR: @r, @p @d",
+					buffer, sizeof(buffer), sms->Number, sizeof(sms->Number),
+					&sms->DateTime, sizeof(sms->DateTime));
 			if (error != ERR_NONE) return error;
 
 			if (!strcmp(buffer,"0") || !strcmp(buffer,"REC UNREAD")) {
@@ -625,7 +469,7 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				} else {
 					sms->Folder = 3; /*INBOX ME*/
 				}
-				sms->InboxFolder = true;
+				sms->InboxFolder = TRUE;
 			} else if (!strcmp(buffer,"1") || !strcmp(buffer,"REC READ")) {
 				smprintf(s, "SMS type - deliver\n");
 				sms->State 	 = SMS_Read;
@@ -635,7 +479,7 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				} else {
 					sms->Folder = 3; /*INBOX ME*/
 				}
-				sms->InboxFolder = true;
+				sms->InboxFolder = TRUE;
 			} else if (!strcmp(buffer,"2") || !strcmp(buffer,"STO UNSENT")) {
 				smprintf(s, "SMS type - submit\n");
 				sms->State 	 = SMS_UnSent;
@@ -645,7 +489,7 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				} else {
 					sms->Folder = 4; /*OUTBOX ME*/
 				}
-				sms->InboxFolder = false;
+				sms->InboxFolder = FALSE;
 			} else if (!strcmp(buffer,"3") || !strcmp(buffer,"STO SENT")) {
 				smprintf(s, "SMS type - submit\n");
 				sms->State 	 = SMS_Sent;
@@ -655,20 +499,38 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				} else {
 					sms->Folder = 4; /*OUTBOX ME*/
 				}
-				sms->InboxFolder = false;
+				sms->InboxFolder = FALSE;
 			}
 
 
-			if (Priv->SMSTextDetails == false) {
+			if (Priv->SMSTextDetails == FALSE) {
 				sms->Class = 1;
 				sms->Coding = SMS_Coding_Default_No_Compression;
 				sms->UDH.Type	= UDH_NoUDH;
-				sms->Length	= GetLineLength(msg.Buffer, &Priv->Lines, 3);
+				sms->Length	= 0;
 				sms->SMSC.Number[0]=0;
 				sms->SMSC.Number[1]=0;
-				sms->ReplyViaSameSMSC=false;
-				return ATGEN_DecodeText(s, GetLineString(msg.Buffer, &Priv->Lines, 3), sms->Length,
-					sms->Text, sizeof(sms->Text), false, false);
+				sms->ReplyViaSameSMSC=FALSE;
+				/* Go trough all lines till OK */
+				for (i = 3; strcmp(line = GetLineString(msg.Buffer, &Priv->Lines, i), "OK") != 0; i++) {
+					if (i > 3) {
+						/* Include new line */
+						sms->Text[(2 * sms->Length) + 0] = 0;
+						sms->Text[(2 * sms->Length) + 1] = '\n';
+						sms->Text[(2 * sms->Length) + 2] = 0;
+						sms->Text[(2 * sms->Length) + 3] = 0;
+						sms->Length++;
+					}
+					length = GetLineLength(msg.Buffer, &Priv->Lines, i);
+					error = ATGEN_DecodeText(s, line, length,
+						sms->Text + (2 * sms->Length),
+						sizeof(sms->Text) - (2 * sms->Length),
+						TRUE, FALSE);
+					if (error != ERR_NONE)
+						return error;
+					sms->Length += length;
+				}
+				return ERR_NONE;
 			}
 
 			/*
@@ -720,7 +582,7 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				sms->SMSC.Number[0]=0;
 				sms->SMSC.Number[1]=0;
 				sms->PDU = SMS_Status_Report;
-				sms->ReplyViaSameSMSC=false;
+				sms->ReplyViaSameSMSC=FALSE;
 			} else {
 				/* Sender number */
 				/* FIXME: support for all formats */
@@ -758,9 +620,9 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 				/* First byte */
 				current+=ATGEN_ExtractOneParameter(msg.Buffer+current, buffer);
 				firstbyte=atoi(buffer);
-				sms->ReplyViaSameSMSC=false;
+				sms->ReplyViaSameSMSC=FALSE;
 				/* GSM 03.40 section 9.2.3.17 (TP-Reply-Path) */
-				if ((firstbyte & 128)==128) sms->ReplyViaSameSMSC=true;
+				if ((firstbyte & 128)==128) sms->ReplyViaSameSMSC=TRUE;
 				/* TP PID */
 				current+=ATGEN_ExtractOneParameter(msg.Buffer+current, buffer);
 				sms->ReplaceMessage = 0;
@@ -861,7 +723,7 @@ GSM_Error ATGEN_GetSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms)
 	/* Clear SMS structure of any possible junk */
 	GSM_SetDefaultReceivedSMSData(&sms->SMS[0]);
 
-	error = ATGEN_GetSMSLocation(s, &sms->SMS[0], &folderid, &location, false);
+	error = ATGEN_GetSMSLocation(s, &sms->SMS[0], &folderid, &location, FALSE);
 	if (error != ERR_NONE) return error;
 	if (Priv->SMSMemory == MEM_ME && GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_SMSME900)) add = 899;
 	sprintf(req, "AT+CMGR=%i\r", location + add);
@@ -926,37 +788,44 @@ GSM_Error ATGEN_ReplyGetMessageList(GSM_Protocol_Message msg, GSM_StateMachine *
 		 */
 		str = strstr(str, "+CMGL:");
 		if (str == NULL) {
-			smprintf(s, "Can not find +CMGL:!\n");
-			return ERR_UNKNOWN;
-		}
-
-		/* Parse reply */
-		error = ATGEN_ParseReply(s, str, "+CMGL: @i, @0", &cur);
-		if (error != ERR_NONE) {
-			return error;
-		}
-		Priv->SMSCount++;
-
-		/* Reallocate buffer if needed */
-		if (allocsize <= Priv->SMSCount) {
-			allocsize += 20;
-			Priv->SMSCache = (GSM_AT_SMS_Cache *)realloc(Priv->SMSCache, allocsize * sizeof(GSM_AT_SMS_Cache));
-			if (Priv->SMSCache == NULL) {
-				return ERR_MOREMEMORY;
+			/*
+			 * Sometimes an SMS message will contain a line break. In SMS text
+                         * mode we skip to the next line and try again to find +CMGL.
+			 * FIXME: Can we do the same for SMS PDU mode?
+			 */
+			if (Priv->SMSMode == SMS_AT_PDU) {
+				smprintf(s, "Can not find +CMGL:!\n");
+				return ERR_UNKNOWN;
 			}
-		}
-
-		/* Should we use index instead of location? Samsung P900 needs this hack. */
-		if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_BROKEN_CMGL)) {
-			ATGEN_SetSMSLocation(s, &sms, Priv->SMSReadFolder, Priv->SMSCount);
 		} else {
-			ATGEN_SetSMSLocation(s, &sms, Priv->SMSReadFolder, cur);
-		}
-		Priv->SMSCache[Priv->SMSCount - 1].Location = sms.Location;
-		Priv->SMSCache[Priv->SMSCount - 1].State = -1;
+			/* Parse reply */
+			error = ATGEN_ParseReply(s, str, "+CMGL: @i, @0", &cur);
+			if (error != ERR_NONE) {
+				return error;
+			}
+			Priv->SMSCount++;
 
-		/* Go to PDU/Text data */
-		line++;
+			/* Reallocate buffer if needed */
+			if (allocsize <= Priv->SMSCount) {
+				allocsize += 20;
+				Priv->SMSCache = (GSM_AT_SMS_Cache *)realloc(Priv->SMSCache, allocsize * sizeof(GSM_AT_SMS_Cache));
+				if (Priv->SMSCache == NULL) {
+					return ERR_MOREMEMORY;
+				}
+			}
+
+			/* Should we use index instead of location? Samsung P900 needs this hack. */
+			if (GSM_IsPhoneFeatureAvailable(s->Phone.Data.ModelInfo, F_BROKEN_CMGL)) {
+				ATGEN_SetSMSLocation(s, &sms, Priv->SMSReadFolder, Priv->SMSCount);
+			} else {
+				ATGEN_SetSMSLocation(s, &sms, Priv->SMSReadFolder, cur);
+			}
+			Priv->SMSCache[Priv->SMSCount - 1].Location = sms.Location;
+			Priv->SMSCache[Priv->SMSCount - 1].State = -1;
+
+			/* Go to PDU/Text data */
+			line++;
+		}
 
 		/* Fill in cache of PDU data */
 		if (Priv->SMSMode == SMS_AT_PDU) {
@@ -990,7 +859,7 @@ GSM_Error ATGEN_ReplyGetMessageList(GSM_Protocol_Message msg, GSM_StateMachine *
 	return ERR_NONE;
 }
 
-GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, bool first)
+GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, gboolean first)
 {
 	GSM_Phone_ATGENData 	*Priv = &s->Phone.Data.Priv.ATGEN;
 	GSM_Error		error;
@@ -1007,11 +876,11 @@ GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, bool first)
 	if (first) {
 		Priv->SMSReadFolder = 1;
 		if (Priv->SIMSMSMemory == AT_AVAILABLE) {
-			error = ATGEN_SetSMSMemory(s, true, false, false);
+			error = ATGEN_SetSMSMemory(s, TRUE, FALSE, FALSE);
 			if (error != ERR_NONE) return error;
 			used = Priv->LastSMSStatus.SIMUsed;
 		} else if (Priv->PhoneSMSMemory == AT_AVAILABLE) {
-			error = ATGEN_SetSMSMemory(s, false, false, false);
+			error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 			if (error != ERR_NONE) return error;
 			used = Priv->LastSMSStatus.PhoneUsed;
 		} else {
@@ -1020,7 +889,7 @@ GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, bool first)
 	} else {
 		Priv->SMSReadFolder = 2;
 		if (Priv->PhoneSMSMemory == AT_AVAILABLE) {
-			error = ATGEN_SetSMSMemory(s, false, false, false);
+			error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 			if (error != ERR_NONE) return error;
 			used = Priv->LastSMSStatus.PhoneUsed;
 		} else {
@@ -1053,12 +922,13 @@ GSM_Error ATGEN_GetSMSList(GSM_StateMachine *s, bool first)
 		Priv->SMSCache = (GSM_AT_SMS_Cache *)realloc(Priv->SMSCache, sizeof(GSM_AT_SMS_Cache));
 	}
 	if (used != Priv->SMSCount && error == ERR_NONE) {
-		smprintf(s, "Used messages according to CPMS %d, but CMGL returned %d. Expect problems!\n", used, Priv->SMSCount);
+		smprintf(s, "WARNING: Used messages according to CPMS %d, but CMGL returned %d. Expect problems!\n", used, Priv->SMSCount);
+		smprintf(s, "HINT: Your might want to use F_USE_SMSTEXTMODE flag\n");
 	}
 	return error;
 }
 
-GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, bool start)
+GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, gboolean start)
 {
 	GSM_Phone_ATGENData 	*Priv = &s->Phone.Data.Priv.ATGEN;
 	GSM_Error 		error;
@@ -1066,11 +936,11 @@ GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, bool s
 	int			i, found = -1, tmpfound = -1;
 
 	if (Priv->PhoneSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, false, false, false);
+		error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, true, false, false);
+		error = ATGEN_SetSMSMemory(s, TRUE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == AT_NOTAVAILABLE && Priv->PhoneSMSMemory == AT_NOTAVAILABLE) return ERR_NOTSUPPORTED;
@@ -1081,7 +951,7 @@ GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, bool s
 		sms->SMS[0].Location 		= 0;
 
 		/* Get list of messages */
-		error = ATGEN_GetSMSList(s, true);
+		error = ATGEN_GetSMSList(s, TRUE);
 	}
 
 	/* Use listed locations if we have them */
@@ -1119,7 +989,7 @@ GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, bool s
 			if (Priv->SMSReadFolder == 2) return ERR_EMPTY;
 
 			/* Get list of messages */
-			error = ATGEN_GetSMSList(s, false);
+			error = ATGEN_GetSMSList(s, FALSE);
 			/* Not supported folder? We're done then. */
 			if (error == ERR_NOTSUPPORTED) return ERR_EMPTY;
 			if (error != ERR_NONE) return error;
@@ -1161,7 +1031,7 @@ GSM_Error ATGEN_GetNextSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms, bool s
 	}
 
 	/* Use brute force if listing does not work */
-	while (true) {
+	while (TRUE) {
 		sms->SMS[0].Location++;
 		if (sms->SMS[0].Location < GSM_PHONE_MAXSMSINFOLDER) {
 			if (Priv->SIMSMSMemory == AT_AVAILABLE) {
@@ -1280,11 +1150,11 @@ GSM_Error ATGEN_GetSMSStatus(GSM_StateMachine *s, GSM_SMSMemoryStatus *status)
 	}
 
 	if (Priv->PhoneSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, false, false, false);
+		error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, true, false, false);
+		error = ATGEN_SetSMSMemory(s, TRUE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 
@@ -1292,10 +1162,10 @@ GSM_Error ATGEN_GetSMSStatus(GSM_StateMachine *s, GSM_SMSMemoryStatus *status)
 		smprintf(s, "Getting SIM SMS status\n");
 		if (Priv->SIMSaveSMS == AT_AVAILABLE) {
 			ATGEN_WaitFor(s, "AT+CPMS=\"SM\",\"SM\"\r", 18, 0x00, 20, ID_GetSMSStatus);
-			Priv->SMSMemoryWrite = true;
+			Priv->SMSMemoryWrite = TRUE;
 		} else {
 			ATGEN_WaitFor(s, "AT+CPMS=\"SM\"\r", 13, 0x00, 20, ID_GetSMSStatus);
-			Priv->SMSMemoryWrite = false;
+			Priv->SMSMemoryWrite = FALSE;
 		}
 		if (error!=ERR_NONE) return error;
 		Priv->SMSMemory = MEM_SM;
@@ -1310,14 +1180,14 @@ GSM_Error ATGEN_GetSMSStatus(GSM_StateMachine *s, GSM_SMSMemoryStatus *status)
 		if (Priv->PhoneSaveSMS == AT_AVAILABLE) {
 			if (Priv->MotorolaSMS) {
 				ATGEN_WaitFor(s, "AT+CPMS=\"MT\"\r", 13, 0x00, 20, ID_GetSMSStatus);
-				Priv->SMSMemoryWrite = false;
+				Priv->SMSMemoryWrite = FALSE;
 			} else {
 				ATGEN_WaitFor(s, "AT+CPMS=\"ME\",\"ME\"\r", 18, 0x00, 20, ID_GetSMSStatus);
-				Priv->SMSMemoryWrite = true;
+				Priv->SMSMemoryWrite = TRUE;
 			}
 		} else {
 			ATGEN_WaitFor(s, "AT+CPMS=\"ME\"\r", 13, 0x00, 20, ID_GetSMSStatus);
-			Priv->SMSMemoryWrite = false;
+			Priv->SMSMemoryWrite = FALSE;
 		}
 		if (error!=ERR_NONE) return error;
 		Priv->SMSMemory = MEM_ME;
@@ -1337,7 +1207,7 @@ GSM_Error ATGEN_ReplyAddSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 		if (s->Phone.Data.Priv.ATGEN.ReplyState != AT_Reply_SMSEdit) {
 			return ATGEN_HandleCMSError(s);
 		}
-		s->Protocol.Data.AT.EditMode = false;
+		s->Protocol.Data.AT.EditMode = FALSE;
 		return ERR_NONE;
 	}
 
@@ -1360,7 +1230,7 @@ GSM_Error ATGEN_ReplyAddSMSMessage(GSM_Protocol_Message msg, GSM_StateMachine *s
 		/* Adjust location */
 		folder = s->Phone.Data.SaveSMSMessage->Folder;
 		ATGEN_SetSMSLocation(s, s->Phone.Data.SaveSMSMessage,
-				1 + (folder / 2), /* We care only about SIM/Phone */
+				(folder / 2), /* We care only about SIM/Phone */
 				s->Phone.Data.SaveSMSMessage->Location);
 		s->Phone.Data.SaveSMSMessage->Folder = folder;
 		return ERR_NONE;
@@ -1396,7 +1266,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 	case SMS_AT_PDU:
 		if (message->PDU == SMS_Deliver) {
  			smprintf(s, "SMS Deliver\n");
-			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSDeliver,&length,true);
+			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSDeliver,&length,TRUE);
 			if (error != ERR_NONE) return error;
 			length = length - PHONE_SMSDeliver.Text;
 			for (i=0;i<buffer[PHONE_SMSDeliver.SMSCNumber]+1;i++) {
@@ -1416,7 +1286,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 			*current = *current - (req[PHONE_SMSDeliver.SMSCNumber]+1);
 		} else {
 			smprintf(s, "SMS Submit\n");
-			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSSubmit,&length,true);
+			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSSubmit,&length,TRUE);
 			if (error != ERR_NONE) return error;
 			length = length - PHONE_SMSSubmit.Text;
 			for (i=0;i<buffer[PHONE_SMSSubmit.SMSCNumber]+1;i++) {
@@ -1444,7 +1314,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 		if (Priv->Manufacturer != AT_Nokia) {
 			if (message->Coding != SMS_Coding_Default_No_Compression) return ERR_NOTSUPPORTED;
 		}
-		error=PHONE_EncodeSMSFrame(s,message,req,PHONE_SMSDeliver,&i,true);
+		error=PHONE_EncodeSMSFrame(s,message,req,PHONE_SMSDeliver,&i,TRUE);
 		if (error != ERR_NONE) return error;
 		CopyUnicodeString(SMSC.Number,message->SMSC.Number);
 		SMSC.Location=1;
@@ -1475,7 +1345,7 @@ GSM_Error ATGEN_MakeSMSFrame(GSM_StateMachine *s, GSM_SMSMessage *message, unsig
 			}
 	        case SMS_Coding_Unicode_No_Compression:
 	        case SMS_Coding_8bit:
-			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSDeliver,current,true);
+			error=PHONE_EncodeSMSFrame(s,message,buffer,PHONE_SMSDeliver,current,TRUE);
 			if (error != ERR_NONE) return error;
 			EncodeHexBin (hexreq, buffer+PHONE_SMSDeliver.Text, buffer[PHONE_SMSDeliver.TPUDL]);
 			*length2 = buffer[PHONE_SMSDeliver.TPUDL] * 2;
@@ -1516,7 +1386,7 @@ GSM_Error ATGEN_AddSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 	sms->Location = 0;
 
 	/* Set correct memory type */
-	error = ATGEN_GetSMSLocation(s, sms, &folderid, &location, true);
+	error = ATGEN_GetSMSLocation(s, sms, &folderid, &location, TRUE);
 	if (error != ERR_NONE) {
 		return error;
 	}
@@ -1531,8 +1401,8 @@ GSM_Error ATGEN_AddSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 
 		if (sms->Memory == MEM_ME &&
 			GSM_IsPhoneFeatureAvailable(Phone->ModelInfo, F_SUBMIT_SIM_ONLY)) {
-			smprintf(s, "This phone do not support saving submit messages to ME location!\n");
-			return ERR_WRONGFOLDER;
+			smprintf(s, "This phone probably does not support saving submit messages to ME location!\n");
+			smprintf(s, "But trying anyway...\n");
 		}
 	}
 
@@ -1594,7 +1464,7 @@ GSM_Error ATGEN_AddSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 		if (reply!=0) {
 			smprintf_level(s, D_ERROR, "[Retrying %i]\n", reply+1);
 		}
-		s->Protocol.Data.AT.EditMode 	= true;
+		s->Protocol.Data.AT.EditMode 	= TRUE;
 		Replies 			= s->ReplyNum;
 		s->ReplyNum			= 1;
 		smprintf(s,"Waiting for modem prompt\n");
@@ -1636,7 +1506,7 @@ GSM_Error ATGEN_ReplySendSMS(GSM_Protocol_Message msg, GSM_StateMachine *s)
 		if (s->Phone.Data.Priv.ATGEN.ReplyState != AT_Reply_SMSEdit) {
 			return ERR_UNKNOWN;
 		}
-		s->Protocol.Data.AT.EditMode = false;
+		s->Protocol.Data.AT.EditMode = FALSE;
 		return ERR_NONE;
 	}
 
@@ -1703,7 +1573,7 @@ GSM_Error ATGEN_SendSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 		sprintf(buffer, "AT+CMGS=\"%s\"\r",DecodeUnicodeString(sms->Number));
 	}
 
-	s->Protocol.Data.AT.EditMode 	= true;
+	s->Protocol.Data.AT.EditMode 	= TRUE;
 	Replies 			= s->ReplyNum;
 	s->ReplyNum			= 1;
 	smprintf(s,"Waiting for modem prompt\n");
@@ -1754,7 +1624,7 @@ GSM_Error ATGEN_SendSavedSMS(GSM_StateMachine *s, int Folder, int Location)
 	msms.SMS[0].Memory	= 0;
 
 	/* Adjust location to real ones */
-	error=ATGEN_GetSMSLocation(s, &msms.SMS[0], &smsfolder, &location, false);
+	error=ATGEN_GetSMSLocation(s, &msms.SMS[0], &smsfolder, &location, FALSE);
 	if (error != ERR_NONE) return error;
 
 	sprintf(req, "AT+CMSS=%i\r",location);
@@ -1875,7 +1745,7 @@ GSM_Error ATGEN_DeleteSMS(GSM_StateMachine *s, GSM_SMSMessage *sms)
 	error = ATGEN_GetSMS(s, &msms);
 	if (error != ERR_NONE) return error;
 
-	error = ATGEN_GetSMSLocation(s, sms, &folderid, &location, true);
+	error = ATGEN_GetSMSLocation(s, sms, &folderid, &location, TRUE);
 	if (error != ERR_NONE) return error;
 
 	sprintf(req, "AT+CMGD=%i\r",location);
@@ -1893,11 +1763,11 @@ GSM_Error ATGEN_GetSMSFolders(GSM_StateMachine *s, GSM_SMSFolders *folders)
 	int			used = 0;
 
 	if (Priv->PhoneSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, false, false, false);
+		error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, true, false, false);
+		error = ATGEN_SetSMSMemory(s, TRUE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 
@@ -1935,7 +1805,7 @@ GSM_Error ATGEN_IncomingSMSCInfo(GSM_Protocol_Message msg UNUSED, GSM_StateMachi
 	return ERR_NONE;
 }
 
-GSM_Error ATGEN_SetFastSMSSending(GSM_StateMachine *s, bool enable)
+GSM_Error ATGEN_SetFastSMSSending(GSM_StateMachine *s, gboolean enable)
 {
 	GSM_Error 		error;
 
@@ -1962,13 +1832,13 @@ GSM_Error ATGEN_IncomingSMSInfo(GSM_Protocol_Message msg, GSM_StateMachine *s)
 	smprintf(s, "Incoming SMS\n");
 	if (Data->EnableIncomingSMS && s->User.IncomingSMS!=NULL) {
 		sms.State 	 = 0;
-		sms.InboxFolder  = true;
+		sms.InboxFolder  = TRUE;
 		sms.PDU 	 = 0;
 
 		buffer = strchr(msg.Buffer, ':');
 		if (buffer == NULL) return ERR_UNKNOWNRESPONSE;
 		buffer++;
-		while (isspace(*buffer)) buffer++;
+		while (isspace((int)*buffer)) buffer++;
 
 		if (strncmp(buffer, "ME", 2) == 0 || strncmp(buffer, "\"ME\"", 4) == 0) {
 			if (Priv->SIMSMSMemory == AT_AVAILABLE) sms.Folder = 3;
@@ -1982,7 +1852,7 @@ GSM_Error ATGEN_IncomingSMSInfo(GSM_Protocol_Message msg, GSM_StateMachine *s)
 		buffer = strchr(msg.Buffer, ',');
 		if (buffer == NULL) return ERR_UNKNOWNRESPONSE;
 		buffer++;
-		while (isspace(*buffer)) buffer++;
+		while (isspace((int)*buffer)) buffer++;
 
 		sms.Location = atoi(buffer);
 
@@ -2001,7 +1871,7 @@ GSM_Error ATGEN_IncomingSMSDeliver(GSM_Protocol_Message msg, GSM_StateMachine *s
 	smprintf(s, "Incoming SMS received (Deliver)\n");
 	if (Data->EnableIncomingSMS && s->User.IncomingSMS!=NULL) {
 		sms.State 	 = SMS_UnRead;
-		sms.InboxFolder  = true;
+		sms.InboxFolder  = TRUE;
 		sms.PDU 	 = SMS_Deliver;
 
 		/* T310 with larger SMS goes crazy and mix this incoming
@@ -2047,7 +1917,7 @@ GSM_Error ATGEN_GetCNMIMode(GSM_StateMachine *s)
 	return error;
 }
 
-GSM_Error ATGEN_SetIncomingCB(GSM_StateMachine *s, bool enable)
+GSM_Error ATGEN_SetIncomingCB(GSM_StateMachine *s, gboolean enable)
 {
 #ifdef GSM_ENABLE_CELLBROADCAST
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
@@ -2083,7 +1953,7 @@ GSM_Error ATGEN_SetIncomingCB(GSM_StateMachine *s, bool enable)
 }
 
 
-GSM_Error ATGEN_SetIncomingSMS(GSM_StateMachine *s, bool enable)
+GSM_Error ATGEN_SetIncomingSMS(GSM_StateMachine *s, gboolean enable)
 {
 	GSM_Phone_ATGENData	*Priv = &s->Phone.Data.Priv.ATGEN;
 	GSM_Error 		error;
@@ -2091,11 +1961,11 @@ GSM_Error ATGEN_SetIncomingSMS(GSM_StateMachine *s, bool enable)
 
 	/* We will need this when incoming message, but we can not invoke AT commands there: */
 	if (Priv->PhoneSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, false, false, false);
+		error = ATGEN_SetSMSMemory(s, FALSE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 	if (Priv->SIMSMSMemory == 0) {
-		error = ATGEN_SetSMSMemory(s, true, false, false);
+		error = ATGEN_SetSMSMemory(s, TRUE, FALSE, FALSE);
 		if (error != ERR_NONE && error != ERR_NOTSUPPORTED) return error;
 	}
 
@@ -2164,7 +2034,7 @@ GSM_Error ATGEN_ReplyIncomingCB(GSM_Protocol_Message msg, GSM_StateMachine *s)
 		while (i!=0) {
 			if (Buffer[i] == 13) i = i - 1; else break;
 		}
-		DecodeDefault(CB.Text, Buffer2, msg.Buffer[6], false, NULL);
+		DecodeDefault(CB.Text, Buffer2, msg.Buffer[6], FALSE, NULL);
 		smprintf(s, "Channel %i, text \"%s\"\n",CB.Channel,DecodeUnicodeString(CB.Text));
 	}
 	if (s->Phone.Data.EnableIncomingCB && s->User.IncomingCB!=NULL) {
