@@ -101,7 +101,7 @@ static GSM_Error GSM_DecodeSMSDateTime(GSM_Debug_Info *di, GSM_DateTime *DT, uns
 
 	if (req[6]&0x08) DT->Timezone = -DT->Timezone;
 
-	smfprintf(di, "Decoding date & time: %s\n", OSDateTime(*DT, true));
+	smfprintf(di, "Decoding date & time: %s\n", OSDateTime(*DT, TRUE));
 
 	return ERR_NONE;
 }
@@ -109,7 +109,7 @@ static GSM_Error GSM_DecodeSMSDateTime(GSM_Debug_Info *di, GSM_DateTime *DT, uns
 void GSM_DecodeUDHHeader(GSM_Debug_Info *di, GSM_UDHHeader *UDH)
 {
 	int	i, tmp, w;
-	bool	UDHOK;
+	gboolean	UDHOK;
 
 	UDH->Type 	= UDH_UserUDH;
 	UDH->ID8bit	= -1;
@@ -128,10 +128,10 @@ void GSM_DecodeUDHHeader(GSM_Debug_Info *di, GSM_UDHHeader *UDH)
 			if (tmp==0x0b) tmp=tmp-3;/*three last bytes can be different for such UDH*/
 			if (tmp==0x06 && UDH->Text[1] == 0x08) tmp=tmp-4;
 
-			UDHOK=true;
+			UDHOK=TRUE;
 			for (w=0;w<tmp;w++) {
 				if (UDHHeaders[i].Text[w]!=UDH->Text[w+1]) {
-					UDHOK=false;
+					UDHOK=FALSE;
 					break;
 				}
 			}
@@ -262,7 +262,7 @@ GSM_Error GSM_DecodeSMSFrameText(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsign
 			}
 			GSM_UnpackEightBitsToSeven(w, buffer[Layout.TPUDL]-off, SMS->Length, buffer+(Layout.Text+off), output);
 			smfprintf(di, "7 bit SMS, length %i\n",SMS->Length);
-			DecodeDefault (SMS->Text, output, SMS->Length, true, NULL);
+			DecodeDefault (SMS->Text, output, SMS->Length, TRUE, NULL);
 			smfprintf(di, "%s\n",DecodeUnicodeString(SMS->Text));
 			break;
 		case SMS_Coding_8bit:
@@ -290,18 +290,18 @@ GSM_Error GSM_DecodeSMSFrameText(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsign
 	return ERR_NONE;
 }
 
-GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, GSM_SMSMessageLayout Layout)
+GSM_Error GSM_DecodeSMSStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage *SMS, int TP_ST)
 {
-	SMS->DeliveryStatus 	= buffer[Layout.TPStatus];
+	SMS->DeliveryStatus 	= TP_ST;
 	SMS->Coding 		= SMS_Coding_Unicode_No_Compression;
 
-	if (buffer[Layout.TPStatus] < 0x03) {
+	if (TP_ST < 0x03) {
 		EncodeUnicode(SMS->Text,"Delivered",9);
 		SMS->Length = 9;
-	} else if (buffer[Layout.TPStatus] & 0x40) {
+	} else if (TP_ST & 0x40) {
 		EncodeUnicode(SMS->Text,"Failed",6);
 		SMS->Length = 6;
-	} else if (buffer[Layout.TPStatus] & 0x20) {
+	} else if (TP_ST & 0x20) {
 		EncodeUnicode(SMS->Text,"Pending",7);
 		SMS->Length = 7;
 	} else {
@@ -311,19 +311,19 @@ GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage
 
 #ifdef DEBUG
 	/* See GSM 03.40 section 9.2.3.15 (TP-Status) */
-	if (buffer[Layout.TPStatus] & 0x40) {
-		if (buffer[Layout.TPStatus] & 0x20) {
+	if (TP_ST & 0x40) {
+		if (TP_ST & 0x20) {
 			/* 0x60, 0x61, ... */
 			smfprintf(di, "Temporary error, SC is not making any more transfer attempts\n");
 		} else {
 			/* 0x40, 0x41, ... */
      			smfprintf(di, "Permanent error, SC is not making any more transfer attempts\n");
 		}
-    	} else if (buffer[Layout.TPStatus] & 0x20) {
+    	} else if (TP_ST & 0x20) {
 		/* 0x20, 0x21, ... */
 		smfprintf(di, "Temporary error, SC still trying to transfer SM\n");
 	}
-	switch (buffer[Layout.TPStatus]) {
+	switch (TP_ST) {
 	case 0x00: smfprintf(di, "SM received by the SME");					break;
 	case 0x01: smfprintf(di, "SM forwarded by the SC to the SME but the SC is unable to confirm delivery");break;
 	case 0x02: smfprintf(di, "SM replaced by the SC");					break;
@@ -349,7 +349,7 @@ GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage
         case 0x63: smfprintf(di, "Service rejected");					break;
         case 0x64: smfprintf(di, "Quality of service not available");			break;
         case 0x65: smfprintf(di, "Error in SME");						break;
-        default  : smfprintf(di, "Reserved/Specific to SC: %x",buffer[Layout.TPStatus]);	break;
+        default  : smfprintf(di, "Reserved/Specific to SC: %x",TP_ST);	break;
 	}
 	smfprintf(di, "\n");
 #endif
@@ -357,6 +357,255 @@ GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage
 	return ERR_NONE;
 }
 
+GSM_Error GSM_DecodeSMSFrameStatusReportData(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, GSM_SMSMessageLayout Layout)
+{
+	return GSM_DecodeSMSStatusReportData(di, SMS, buffer[Layout.TPStatus]);
+}
+
+GSM_Error GSM_DecodePDUFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, size_t length, size_t *final_pos, gboolean SMSC)
+{
+	size_t pos = 0;
+	int type;
+	int vpf = 0;
+	int rp = 0;
+	int udh = 0;
+	int i,w;
+	unsigned char	output[161];
+	int			datalength;
+
+	/* Set some sane data */
+	GSM_SetDefaultReceivedSMSData(SMS);
+
+	/* Parse SMSC if it is included */
+	if (SMSC) {
+		pos += GSM_UnpackSemiOctetNumber(di, SMS->SMSC.Number, buffer + pos, FALSE);
+		smfprintf(di, "SMS center number : \"%s\"\n",DecodeUnicodeString(SMS->SMSC.Number));
+	}
+
+	/* Message type */
+	type = buffer[pos];
+	pos++;
+	switch (type & 0x3) {
+		case 0:
+			smfprintf(di, "SMS type: Deliver");
+			SMS->PDU = SMS_Deliver;
+			break;
+		case 1:
+			smfprintf(di, "SMS type: Submit");
+			SMS->PDU = SMS_Submit;
+			break;
+		case 2:
+			smfprintf(di, "SMS type: Status report");
+			SMS->PDU = SMS_Status_Report;
+			break;
+		case 3:
+			smfprintf(di, "SMS type: Reserverd, aborting!\n");
+			return ERR_UNKNOWN;;
+	}
+
+	if (SMS->PDU == SMS_Submit || SMS->PDU == SMS_Deliver) {
+		if (type & (1 << 7)) {
+			smfprintf(di, ", Reply path set");
+			rp = 1;
+		}
+		if (type & (1 << 6)) {
+			smfprintf(di, ", UDH included");
+			udh = 1;
+		}
+	}
+	if (SMS->PDU == SMS_Submit) {
+		vpf = (type & (0x3 << 3)) >> 3;
+		switch (vpf) {
+			case 0:
+				smfprintf(di, ", No VP");
+				break;
+			case 1:
+				smfprintf(di, ", Reserved VP!\n");
+				return ERR_UNKNOWN;
+			case 2:
+				smfprintf(di, ", Relative VP");
+				break;
+			case 3:
+				smfprintf(di, ", Absolute VP");
+				break;
+		}
+	}
+	smfprintf(di, "\n");
+
+	/* Message reference */
+	if (SMS->PDU == SMS_Submit || SMS->PDU == SMS_Status_Report) {
+		SMS->MessageReference = buffer[pos];
+		smfprintf(di, "SMS MR: 0x%02X\n", SMS->MessageReference);
+		pos++;
+		if (pos >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+	}
+
+	/* Remote number */
+	pos += GSM_UnpackSemiOctetNumber(di, SMS->Number, buffer + pos, TRUE);
+	smfprintf(di, "Remote number : \"%s\"\n",DecodeUnicodeString(SMS->Number));
+	if (pos >= length) {
+		smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+		return ERR_CORRUPTED;
+	}
+
+
+	if (SMS->PDU == SMS_Submit || SMS->PDU == SMS_Deliver) {
+		/* Protocol identifier */
+		smfprintf(di, "SMS PID: 0x%02X\n", buffer[pos]);
+		if (buffer[pos] > 0x40 && buffer[pos] < 0x48) {
+			SMS->ReplaceMessage = buffer[pos];
+		}
+		pos++;
+		if (pos >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+
+		/* Data coding scheme */
+		smfprintf(di, "SMS DCS: 0x%02X\n", buffer[pos]);
+		SMS->Coding = GSM_GetMessageCoding(di, buffer[pos]);
+
+		/* Message class */
+		SMS->Class = -1;
+		/* GSM 03.40 section 9.2.3.10 (TP-Data-Coding-Scheme) and GSM 03.38 section 4 */
+		if ((buffer[pos] & 0xD0) == 0x10 || (buffer[pos] & 0xF0) == 0xF0) {
+			SMS->Class = buffer[pos] & 3;
+		}
+		smfprintf(di, "SMS class: %i\n",SMS->Class);
+
+		pos++;
+		if (pos >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+	}
+
+	/* SMSC time stamp */
+	if (SMS->PDU == SMS_Status_Report || SMS->PDU == SMS_Deliver) {
+		if (pos + 7 >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+		GSM_DecodeSMSDateTime(di, &SMS->DateTime, buffer + pos);
+		pos += 7;
+	}
+
+	if (SMS->PDU == SMS_Status_Report) {
+		/* Discharge Time */
+		if (pos + 7 >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+		GSM_DecodeSMSDateTime(di, &SMS->SMSCTime, buffer + pos);
+		pos += 7;
+
+		/* Status */
+		GSM_DecodeSMSStatusReportData(di, SMS, buffer[pos]);
+		pos++;
+	}
+
+	/* Validity period */
+	if (SMS->PDU == SMS_Submit) {
+		if (vpf == 2) {
+			SMS->SMSC.Validity.Format = SMS_Validity_RelativeFormat;
+			SMS->SMSC.Validity.Relative = buffer[pos];
+			smfprintf(di, "Relative validity: 0x%02X\n", buffer[pos]);
+			pos++;
+			if (pos >= length) {
+				smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+				return ERR_CORRUPTED;
+			}
+		} else if (vpf == 3) {
+			/* @todo TODO: handle absolute validity */
+			smfprintf(di, "Absolute validity not handled!\n");
+			pos += 7;
+			if (pos >= length) {
+				smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+				return ERR_CORRUPTED;
+			}
+		}
+	}
+
+	/* Data */
+	if (SMS->PDU == SMS_Submit || SMS->PDU == SMS_Deliver) {
+		datalength = buffer[pos];
+		if (SMS->Coding == SMS_Coding_Default_No_Compression) {
+			datalength = (datalength * 7) / 8;
+			if ((buffer[pos] * 7) % 8 != 0) {
+				datalength++;
+			}
+		}
+		if (pos + datalength >= length) {
+			smfprintf(di, "Ran out of buffer when parsing PDU!\n");
+			return ERR_CORRUPTED;
+		}
+		if (final_pos != NULL) {
+			*final_pos = pos + datalength + 1;
+		}
+		SMS->UDH.Length = 0;
+		/* UDH header available */
+		if (udh) {
+			/* Length of UDH header */
+			SMS->UDH.Length = (buffer[pos + 1] + 1);
+			smfprintf(di, "UDH header available (length %i)\n",SMS->UDH.Length);
+
+			/* Copy UDH header into SMS->UDH */
+			for (i = 0; i < SMS->UDH.Length; i++) SMS->UDH.Text[i] = buffer[pos + 1 + i];
+
+			GSM_DecodeUDHHeader(di, &SMS->UDH);
+		}
+
+		switch (SMS->Coding) {
+			case SMS_Coding_Default_No_Compression:
+				i = 0;
+				do {
+					i+=7;
+					w=(i-SMS->UDH.Length)%i;
+				} while (w<0);
+				SMS->Length=buffer[pos] - (SMS->UDH.Length*8 + w) / 7;
+				if (SMS->Length < 0) {
+					smfprintf(di, "No SMS text!\n");
+					SMS->Length = 0;
+					break;
+				}
+				GSM_UnpackEightBitsToSeven(w, buffer[pos]-SMS->UDH.Length, SMS->Length, buffer+(pos + 1+SMS->UDH.Length), output);
+				smfprintf(di, "7 bit SMS, length %i\n",SMS->Length);
+				DecodeDefault (SMS->Text, output, SMS->Length, TRUE, NULL);
+				smfprintf(di, "%s\n",DecodeUnicodeString(SMS->Text));
+				break;
+			case SMS_Coding_8bit:
+				SMS->Length=buffer[pos] - SMS->UDH.Length;
+				memcpy(SMS->Text,buffer+(pos + 1+SMS->UDH.Length),SMS->Length);
+#ifdef DEBUG
+				smfprintf(di, "8 bit SMS, length %i\n",SMS->Length);
+				DumpMessageText(di, SMS->Text, SMS->Length);
+#endif
+				break;
+			case SMS_Coding_Unicode_No_Compression:
+				SMS->Length=(buffer[pos] - SMS->UDH.Length) / 2;
+				DecodeUnicodeSpecialNOKIAChars(SMS->Text,buffer+(pos + 1+SMS->UDH.Length), SMS->Length);
+#ifdef DEBUG
+				smfprintf(di, "Unicode SMS, length %i\n",SMS->Length);
+				DumpMessageText(di, buffer+(pos + 1+SMS->UDH.Length), SMS->Length*2);
+				smfprintf(di, "%s\n",DecodeUnicodeString(SMS->Text));
+#endif
+				break;
+			default:
+				SMS->Length=0;
+				break;
+		}
+	} else {
+		if (final_pos != NULL) {
+			*final_pos = pos;
+		}
+	}
+
+	return ERR_NONE;
+}
+
 GSM_Error GSM_DecodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, GSM_SMSMessageLayout Layout)
 {
 	GSM_DateTime	zerodt = {0,0,0,0,0,0,0};
@@ -378,15 +627,15 @@ GSM_Error GSM_DecodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned c
 	GSM_SetDefaultReceivedSMSData(SMS);
 
 	if (Layout.SMSCNumber!=255) {
-		GSM_UnpackSemiOctetNumber(di, SMS->SMSC.Number,buffer+Layout.SMSCNumber,false);
+		GSM_UnpackSemiOctetNumber(di, SMS->SMSC.Number,buffer+Layout.SMSCNumber,FALSE);
 		smfprintf(di, "SMS center number : \"%s\"\n",DecodeUnicodeString(SMS->SMSC.Number));
 	}
-	if ((buffer[Layout.firstbyte] & 0x80)!=0) SMS->ReplyViaSameSMSC=true;
+	if ((buffer[Layout.firstbyte] & 0x80)!=0) SMS->ReplyViaSameSMSC=TRUE;
 #ifdef DEBUG
 	if (SMS->ReplyViaSameSMSC) smfprintf(di, "SMS centre set for reply\n");
 #endif
 	if (Layout.Number!=255) {
-		GSM_UnpackSemiOctetNumber(di, SMS->Number,buffer+Layout.Number,true);
+		GSM_UnpackSemiOctetNumber(di, SMS->Number,buffer+Layout.Number,TRUE);
 		smfprintf(di, "Remote number : \"%s\"\n",DecodeUnicodeString(SMS->Number));
 	}
 	if (Layout.TPDCS != 255) {
@@ -439,8 +688,8 @@ GSM_Error GSM_DecodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned c
 			SMS->ReplaceMessage = buffer[Layout.TPPID] - 0x40;
 		}
 	}
-	SMS->RejectDuplicates = false;
-	if ((buffer[Layout.firstbyte] & 0x04)==0x04) SMS->RejectDuplicates = true;
+	SMS->RejectDuplicates = FALSE;
+	if ((buffer[Layout.firstbyte] & 0x04)==0x04) SMS->RejectDuplicates = TRUE;
 
 	return ERR_NONE;
 }
@@ -509,7 +758,7 @@ static int GSM_EncodeSMSFrameText(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsig
 				w=(p-off)%p;
 			} while (w<0);
 			p = UnicodeLength(SMS->Text);
-			EncodeDefault(buff, SMS->Text, &p, true, NULL);
+			EncodeDefault(buff, SMS->Text, &p, TRUE, NULL);
 			size = GSM_PackSevenBitsToEight(w, buff, buffer+(Layout.Text+off), p);
 			size += off;
 			size2 = (off*8 + w) / 7 + p;
@@ -546,7 +795,7 @@ static int GSM_EncodeSMSFrameText(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsig
 	return size;
 }
 
-GSM_Error GSM_EncodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, GSM_SMSMessageLayout Layout, int *length, bool clear)
+GSM_Error GSM_EncodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned char *buffer, GSM_SMSMessageLayout Layout, int *length, gboolean clear)
 {
 	int i;
 
@@ -576,11 +825,11 @@ GSM_Error GSM_EncodeSMSFrame(GSM_Debug_Info *di, GSM_SMSMessage *SMS, unsigned c
 	if (SMS->ReplyViaSameSMSC) buffer[Layout.firstbyte] |= 0x80;
 
 	if (Layout.Number!=255) {
-		buffer[Layout.Number] = GSM_PackSemiOctetNumber(SMS->Number,buffer+(Layout.Number+1),true);
+		buffer[Layout.Number] = GSM_PackSemiOctetNumber(SMS->Number,buffer+(Layout.Number+1),TRUE);
 		smfprintf(di, "Recipient number \"%s\"\n",DecodeUnicodeString(SMS->Number));
 	}
 	if (Layout.SMSCNumber!=255) {
-		buffer[Layout.SMSCNumber]=GSM_PackSemiOctetNumber(SMS->SMSC.Number,buffer+(Layout.SMSCNumber+1), false);
+		buffer[Layout.SMSCNumber]=GSM_PackSemiOctetNumber(SMS->SMSC.Number,buffer+(Layout.SMSCNumber+1), FALSE);
 		smfprintf(di, "SMSC number \"%s\"\n",DecodeUnicodeString(SMS->SMSC.Number));
 	}
 
@@ -656,14 +905,15 @@ void GSM_SetDefaultReceivedSMSData(GSM_SMSMessage *SMS)
 	SMS->OtherNumbersNum		= 0;
 	SMS->Name[0]			= 0;
 	SMS->Name[1]			= 0;
-	SMS->ReplyViaSameSMSC		= false;
+	SMS->ReplyViaSameSMSC		= FALSE;
 	SMS->Class			= 0;
 	SMS->Text[0] 			= 0;
 	SMS->Text[1] 			= 0;
-	SMS->RejectDuplicates		= false;
+	SMS->RejectDuplicates		= FALSE;
 	SMS->MessageReference		= 0;
 	SMS->ReplaceMessage		= 0;
 	SMS->DeliveryStatus		= 0;
+	SMS->DateTime.Year = 0;
 }
 
 void GSM_SetDefaultSMSData(GSM_SMSMessage *SMS)
@@ -680,7 +930,7 @@ void GSM_SetDefaultSMSData(GSM_SMSMessage *SMS)
 	SMS->Location			= 0;
 	SMS->Memory			= 0;
 	SMS->Folder			= 0x02;	/*Outbox*/
-	SMS->InboxFolder		= false;
+	SMS->InboxFolder		= FALSE;
 	GSM_GetCurrentDateTime (&SMS->DateTime);
 	GSM_GetCurrentDateTime (&SMS->SMSCTime);
 }
@@ -700,7 +950,7 @@ void GSM_EncodeUDHHeader(GSM_Debug_Info *di, GSM_UDHHeader *UDH)
 		UDH->Length = UDH->Text[0] + 1;
 		return;
 	}
-	while (true) {
+	while (TRUE) {
 		if (UDHHeaders[i].Type==UDH_NoUDH) {
 			smfprintf(di, "Not supported UDH type\n");
 			break;
@@ -739,19 +989,19 @@ void GSM_EncodeUDHHeader(GSM_Debug_Info *di, GSM_UDHHeader *UDH)
 	}
 }
 
-bool GSM_DecodeSiemensOTASMS(GSM_Debug_Info *di, GSM_SiemensOTASMSInfo	*Info,
+gboolean GSM_DecodeSiemensOTASMS(GSM_Debug_Info *di, GSM_SiemensOTASMSInfo	*Info,
 			     GSM_SMSMessage 		*SMS)
 {
 	int current;
 
-	if (SMS->PDU != SMS_Deliver) 		return false;
-	if (SMS->Coding != SMS_Coding_8bit) 	return false;
-	if (SMS->Class != 1) 			return false;
-	if (SMS->UDH.Type != UDH_NoUDH) 	return false;
-	if (SMS->Length < 22) 			return false;
+	if (SMS->PDU != SMS_Deliver) 		return FALSE;
+	if (SMS->Coding != SMS_Coding_8bit) 	return FALSE;
+	if (SMS->Class != 1) 			return FALSE;
+	if (SMS->UDH.Type != UDH_NoUDH) 	return FALSE;
+	if (SMS->Length < 22) 			return FALSE;
 
-	if (strncmp(SMS->Text,"//SEO",5)!=0) return false; /* Siemens Exchange Object */
-	if (SMS->Text[5]!=1) return false; /* version 1 */
+	if (strncmp(SMS->Text,"//SEO",5)!=0) return FALSE; /* Siemens Exchange Object */
+	if (SMS->Text[5]!=1) return FALSE; /* version 1 */
 	Info->DataLen = SMS->Text[6] + SMS->Text[7]*256;
 	Info->SequenceID = SMS->Text[8] + SMS->Text[9]*256 +
 			 SMS->Text[10]*256*256 + SMS->Text[11]*256*256*256;
@@ -762,13 +1012,13 @@ bool GSM_DecodeSiemensOTASMS(GSM_Debug_Info *di, GSM_SiemensOTASMSInfo	*Info,
 			 SMS->Text[18]*256*256 + SMS->Text[19]*256*256*256;
 	smfprintf(di, "DataLen %i/%lu\n",Info->DataLen,Info->AllDataLen);
 
-	if (SMS->Text[20] > 9) return false;
+	if (SMS->Text[20] > 9) return FALSE;
 	memcpy(Info->DataType,SMS->Text+21,SMS->Text[20]);
 	Info->DataType[SMS->Text[20]] = 0;
 	smfprintf(di, "DataType '%s'\n",Info->DataType);
 
 	current = 21+SMS->Text[20];
-	if (SMS->Text[current] > 39) return false;
+	if (SMS->Text[current] > 39) return FALSE;
 	memcpy(Info->DataName,SMS->Text+current+1,SMS->Text[current]);
 	Info->DataName[SMS->Text[current]] = 0;
 	smfprintf(di, "DataName '%s'\n",Info->DataName);
@@ -776,7 +1026,7 @@ bool GSM_DecodeSiemensOTASMS(GSM_Debug_Info *di, GSM_SiemensOTASMSInfo	*Info,
 	current += SMS->Text[current]+1;
 	memcpy(Info->Data,SMS->Text+current,Info->DataLen);
 
-	return true;
+	return TRUE;
 }
 
 /* How should editor hadle tabs in this file? Add editor commands here.
