@@ -29,7 +29,9 @@ char *SMSValidityToString(GSM_SMSValidity Validity) {
 
     switch (Validity.Format) {
         case SMS_Validity_NotAvailable:
+#if 0
         case 0:
+#endif
             strcpy(s, "NA");
             break;
         case SMS_Validity_RelativeFormat:
@@ -76,7 +78,7 @@ GSM_SMSValidity StringToSMSValidity(char *s){
     }
     len = strlen(s);
     type = s[len - 1];
-    if (isdigit(type)) type = 'M';
+    if (isdigit((int)type)) type = 'M';
     val = atoi(s);
 
     if (val <= 0) {
@@ -211,7 +213,7 @@ PyObject *SMSCToPython(GSM_SMSC *smsc) {
     return ret;
 }
 
-int SMSCFromPython(PyObject* dict, GSM_SMSC *smsc, bool complete) {
+int SMSCFromPython(PyObject* dict, GSM_SMSC *smsc, gboolean complete) {
     char    *s;
 
     if (!PyDict_Check(dict)) {
@@ -601,7 +603,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
         return 0;
     }
 
-    if (!SMSCFromPython(o, &(sms->SMSC), false)) {
+    if (!SMSCFromPython(o, &(sms->SMSC), FALSE)) {
         return 0;
     }
 
@@ -673,7 +675,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
         }
     }
     if ((sms->InboxFolder = GetBoolFromDict(dict, "InboxFolder")) == BOOL_INVALID) {
-        sms->InboxFolder = false;
+        sms->InboxFolder = FALSE;
         PyErr_Clear();
     }
     if ((i = GetIntFromDict(dict, "DeliveryStatus")) == INT_INVALID) {
@@ -684,7 +686,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
     }
 
     if ((i = GetIntFromDict(dict, "ReplyViaSameSMSC")) == INT_INVALID) {
-        sms->ReplyViaSameSMSC = false;
+        sms->ReplyViaSameSMSC = FALSE;
         PyErr_Clear();
     } else {
         sms->ReplyViaSameSMSC = i;
@@ -708,7 +710,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
         sms->ReplaceMessage = i;
     }
     if ((sms->RejectDuplicates = GetBoolFromDict(dict, "RejectDuplicates")) == BOOL_INVALID) {
-        sms->RejectDuplicates = false;
+        sms->RejectDuplicates = FALSE;
         PyErr_Clear();
     }
 
@@ -1642,7 +1644,7 @@ int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
             PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate structure");
             return 0;
         }
-        if (!MemoryEntryFromPython(o, entry->Phonebook, false)) {
+        if (!MemoryEntryFromPython(o, entry->Phonebook, FALSE)) {
             return 0;
         }
     }
@@ -1654,7 +1656,7 @@ int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
             PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate structure");
             return 0;
         }
-        if (!CalendarFromPython(o, entry->Calendar, false)) {
+        if (!CalendarFromPython(o, entry->Calendar, FALSE)) {
             return 0;
         }
     }
@@ -1666,7 +1668,7 @@ int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
             PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate structure");
             return 0;
         }
-        if (!TodoFromPython(o, entry->ToDo, false)) {
+        if (!TodoFromPython(o, entry->ToDo, FALSE)) {
             return 0;
         }
     }
@@ -1678,7 +1680,7 @@ int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
             PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate structure");
             return 0;
         }
-        if (!FileFromPython(o, entry->File, false)) {
+        if (!FileFromPython(o, entry->File, FALSE)) {
             return 0;
         }
     }
@@ -1721,7 +1723,7 @@ int SMSInfoFromPython(PyObject *dict, GSM_MultiPartSMSInfo *entry) {
     entry->Unknown = GetBoolFromDict(dict, "Unknown");
     if (entry->Unknown == BOOL_INVALID) {
         PyErr_Clear();
-        entry->Unknown = false;
+        entry->Unknown = FALSE;
     }
 
     i = GetIntFromDict(dict, "Class");
