@@ -7,6 +7,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdarg.h>
 #include <errno.h>
 #include <time.h>
 #include <assert.h>
@@ -19,8 +20,82 @@
 
 #include "../core.h"
 
+static GSM_Error SMSDPgSQL_Connect(GSM_SMSDConfig * Config);
+static GSM_Error SMSDPgSQL_Free(GSM_SMSDConfig *Config);
+static GSM_Error SMSDPgSQL_Query(GSM_SMSDConfig * Config, PGresult **Res, const char *fmt, ...) PRINTF_STYLE(3, 4);
+
+struct _TableCheck
+{
+	const char *query;
+	const char *msg;
+} TableCheck;
+
+static struct _TableCheck	tc[] =
+{
+	{ "SELECT id FROM outbox", "No table for outbox sms" },
+	{ "SELECT id FROM outbox_multipart", "No table for outbox multipart sms" },
+	{ "SELECT id FROM sentitems", "No table for sent sms" },
+	{ "SELECT id FROM inbox", "No table for inbox sms" },
+/*	{ "SELECT Version FROM gammu", "No Gammu table" }, */
+	{ NULL, NULL },
+};
+
 /* Connects to database */
 static GSM_Error SMSDPgSQL_Init(GSM_SMSDConfig * Config)
+{
+	char buf[400];
+	PGresult *Res;
+	int s;
+	struct _TableCheck *T;
+
+	Config->DBConnPgSQL = NULL;
+
+	if ((s = SMSDPgSQL_Connect(Config)) != ERR_NONE)
+		return s;
+
+	for (T = tc; T->query; T++) {
+		sprintf(buf, "%s WHERE TRUE", T->query);
+		Res = PQexec(Config->DBConnPgSQL, buf);
+		if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
+			SMSD_Log(DEBUG_ERROR, Config, "%s: %s", T->msg, PQresultErrorMessage(Res));
+			PQclear(Res);
+			SMSDPgSQL_Free(Config);
+			return ERR_UNKNOWN;
+		}
+
+		PQclear(Res);
+	}
+
+	snprintf(buf, sizeof(buf), "SELECT Version FROM gammu WHERE TRUE");
+	Res = PQexec(Config->DBConnPgSQL, buf);
+	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
+		SMSD_Log(DEBUG_ERROR, Config, "No Gammu table: %s",
+			     PQresultErrorMessage(Res));
+		PQclear(Res);
+		SMSDPgSQL_Free(Config);
+		return ERR_UNKNOWN;
+	}
+	if (PQntuples(Res) == 0) {
+		SMSD_Log(DEBUG_ERROR, Config, "No version info in Gammu table: %s",
+			     PQresultErrorMessage(Res));
+		PQclear(Res);
+		SMSDPgSQL_Free(Config);
+		return ERR_UNKNOWN;
+	}
+	if (SMSD_CheckDBVersion(Config, atoi(PQgetvalue(Res, 0, 0))) != ERR_NONE) {
+		PQclear(Res);
+		PQfinish(Config->DBConnPgSQL);
+		return ERR_UNKNOWN;
+	}
+	PQclear(Res);
+
+	SMSD_Log(DEBUG_INFO, Config, "Table check succeeded");
+
+	return ERR_NONE;
+}
+
+/* [Re]connects to database */
+static GSM_Error SMSDPgSQL_Connect(GSM_SMSDConfig * Config)
 {
 	unsigned char buf[400];
 	PGresult *Res;
@@ -39,85 +114,20 @@ static GSM_Error SMSDPgSQL_Init(GSM_SMSDConfig * Config)
 		Config->PC, Config->user, Config->password, Config->database,
 		port);
 
+	SMSDPgSQL_Free(Config);
 	Config->DBConnPgSQL = PQconnectdb(buf);
 	if (PQstatus(Config->DBConnPgSQL) != CONNECTION_OK) {
-		SMSD_Log(-1, Config, "Error connecting to database: %s",
+		SMSD_Log(DEBUG_ERROR, Config, "Error connecting to database: %s",
 			     PQerrorMessage(Config->DBConnPgSQL));
 		PQfinish(Config->DBConnPgSQL);
 		return ERR_UNKNOWN;
 	}
 
-	sprintf(buf, "SELECT id FROM outbox WHERE TRUE");
-	Res = PQexec(Config->DBConnPgSQL, buf);
-	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	PQclear(Res);
-
-	sprintf(buf, "SELECT id FROM outbox_multipart WHERE TRUE");
-	Res = PQexec(Config->DBConnPgSQL, buf);
-	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(-1, Config, "No table for outbox sms: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	PQclear(Res);
-
-	sprintf(buf, "SELECT id FROM sentitems WHERE TRUE");
-	Res = PQexec(Config->DBConnPgSQL, buf);
-	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(-1, Config, "No table for sent sms: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	PQclear(Res);
-
-	sprintf(buf, "SELECT id FROM inbox WHERE TRUE");
-	Res = PQexec(Config->DBConnPgSQL, buf);
-	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(-1, Config, "No table for inbox sms: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	PQclear(Res);
-
-	sprintf(buf, "SELECT Version FROM gammu WHERE TRUE");
-	Res = PQexec(Config->DBConnPgSQL, buf);
-	if ((!Res) || (PQresultStatus(Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(-1, Config, "No Gammu table: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	if (PQntuples(Res) == 0) {
-		SMSD_Log(-1, Config, "No version info in Gammu table: %s",
-			     PQresultErrorMessage(Res));
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	if (SMSD_CheckDBVersion(Config, atoi(PQgetvalue(Res, 0, 0))) != ERR_NONE) {
-		PQclear(Res);
-		PQfinish(Config->DBConnPgSQL);
-		return ERR_UNKNOWN;
-	}
-	PQclear(Res);
-
 	Res = PQexec(Config->DBConnPgSQL, "SET NAMES UTF8");
 	PQclear(Res);
-
-	SMSD_Log(0, Config, "Connected to Database: %s on %s", Config->database, Config->PC);
+	SMSD_Log(DEBUG_INFO, Config, "Connected to database: %s on %s. Server version: %d Protocol: %d",
+			PQdb(Config->DBConnPgSQL), PQhost(Config->DBConnPgSQL),
+			PQserverVersion(Config->DBConnPgSQL), PQprotocolVersion(Config->DBConnPgSQL));
 
 	return ERR_NONE;
 }
@@ -126,7 +136,7 @@ static GSM_Error SMSDPgSQL_Init(GSM_SMSDConfig * Config)
 static GSM_Error SMSDPgSQL_Free(GSM_SMSDConfig *Config)
 {
 	if (Config->DBConnPgSQL != NULL) {
-		SMSD_Log(1, Config, "Disconnecting from PostgreSQL");
+		SMSD_Log(DEBUG_NOTICE, Config, "Disconnecting from PostgreSQL");
 		PQfinish(Config->DBConnPgSQL);
 		Config->DBConnPgSQL = NULL;
 	}
@@ -137,39 +147,90 @@ static GSM_Error SMSDPgSQL_Free(GSM_SMSDConfig *Config)
 static void SMSDPgSQL_LogError(GSM_SMSDConfig *Config, PGresult *Res)
 {
 	if (Res == NULL) {
-		SMSD_Log(0, Config, "Error: %s", PQerrorMessage(Config->DBConnPgSQL));
+		SMSD_Log(DEBUG_INFO, Config, "Error: %s", PQerrorMessage(Config->DBConnPgSQL));
 	} else {
-		SMSD_Log(0, Config, "Error: %s", PQresultErrorMessage(Res));
+		SMSD_Log(DEBUG_INFO, Config, "Error: %s", PQresultErrorMessage(Res));
 	}
 }
 
-static GSM_Error SMSDPgSQL_Query(GSM_SMSDConfig * Config, const char *query, PGresult **Res)
+static GSM_Error SMSDPgSQL_Query(GSM_SMSDConfig * Config, PGresult **Res, const char *fmt, ...)
 {
-	SMSD_Log(2, Config, "Execute SQL: %s", query);
+	char query[8192];
+	va_list args;
+	ExecStatusType Status = PGRES_COMMAND_OK;
+
+	va_start(args, fmt);
+	vsprintf(query, fmt, args);
+	va_end(args);
+
+	SMSD_Log(DEBUG_SQL, Config, "Execute SQL: %s", query);
 
 	*Res = PQexec(Config->DBConnPgSQL, query);
-	if ((*Res == NULL) || (PQresultStatus(*Res) != PGRES_COMMAND_OK && PQresultStatus(*Res) != PGRES_TUPLES_OK)) {
-		SMSD_Log(0, Config, "SQL failed: %s", query);
+	if ((*Res == NULL) || ((Status = PQresultStatus(*Res)) != PGRES_COMMAND_OK && (Status != PGRES_TUPLES_OK))) {
+		SMSD_Log(DEBUG_INFO, Config, "SQL failed: %s", query);
 		SMSDPgSQL_LogError(Config, *Res);
+
+		/* Check for reconnect */
+		if ((*Res == NULL) || (Status == PGRES_FATAL_ERROR)) {
+			/* Dirty hack */
+			*Res = PQexec(Config->DBConnPgSQL, "SELECT 42");
+			if (*Res != NULL)
+				PQclear(*Res);
+			SMSD_Log(DEBUG_INFO, Config, "Query failed, checking connection");
+			if (PQstatus(Config->DBConnPgSQL) != CONNECTION_OK) {
+				SMSD_Log(DEBUG_INFO, Config, "SQL connection failed. Reconnecting");
+
+				if (SMSDPgSQL_Connect(Config) != ERR_NONE)
+					return ERR_UNKNOWN;
+
+				/* Connected. Let's re-issue query */
+				*Res = PQexec(Config->DBConnPgSQL, query);
+				if ((*Res == NULL) || ((Status = PQresultStatus(*Res)) != PGRES_COMMAND_OK && (Status != PGRES_TUPLES_OK))) {
+					SMSD_Log(DEBUG_INFO, Config, "SQL failed: %s", query);
+					SMSDPgSQL_LogError(Config, *Res);
+					if (*Res != NULL) {
+						PQclear(*Res);
+						*Res = NULL;
+					}
+
+					return ERR_UNKNOWN;
+				}
+
+				return ERR_NONE;
+			}
+
+		}
+
 		if (*Res != NULL) {
 			PQclear(*Res);
 			*Res = NULL;
 		}
+
+
 		return ERR_UNKNOWN;
 	}
 	return ERR_NONE;
 }
 
+/* Assume 2 * strlen(from) + 1 buffer in to */
+static size_t SMSDPgSQL_Escape(GSM_SMSDConfig * Config, char *to, char *from)
+{
+	/* Not much sense since we have only 1 DB connection */
+#ifdef HAVE_PQESCAPESTRINGCONN
+	return PQescapeStringConn(Config->DBConnPgSQL, to, from, strlen(from), NULL);
+#else
+	return PQescapeString(to, from, strlen(from));
+#endif
+}
+
 static GSM_Error SMSDPgSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 {
-	unsigned char buf[400], buf2[200];
+	unsigned char buf2[200];
 
 	PGresult *Res;
 
-	sprintf(buf, "DELETE FROM phones WHERE IMEI = '%s'", Config->Status->IMEI);
-
-	if (SMSDPgSQL_Query(Config, buf, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s)", __FUNCTION__);
+	if (SMSDPgSQL_Query(Config, &Res, "DELETE FROM phones WHERE IMEI = '%s'", Config->Status->IMEI) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	PQclear(Res);
@@ -184,13 +245,12 @@ static GSM_Error SMSDPgSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 		strcat(buf2 + strlen(buf2), GetCompiler());
 	}
 
-	sprintf(buf,
-		"INSERT INTO phones (IMEI, ID, Send, Receive, InsertIntoDB, TimeOut, Client, Battery, Signal) VALUES ('%s', '%s', 'yes', 'yes', now(), now() + interval '10 seconds', '%s', -1, -1)",
-		Config->Status->IMEI, Config->PhoneID, buf2);
-
-	if (SMSDPgSQL_Query(Config, buf, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error inserting into database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+	if (SMSDPgSQL_Query(Config, &Res,
+		"INSERT INTO phones (IMEI, ID, Send, Receive, InsertIntoDB, TimeOut, Client, Battery, Signal) "
+		"VALUES ('%s', '%s', 'yes', 'yes', now(), now() + interval '10 seconds', '%s', -1, -1)",
+		Config->Status->IMEI, Config->PhoneID, buf2) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error inserting into database (%s)", __FUNCTION__);
+			return ERR_UNKNOWN;
 	}
 	PQclear(Res);
 
@@ -209,7 +269,7 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 	int i, j;
 	int numb_rows;
 	time_t t_time1, t_time2;
-	bool found;
+	gboolean found;
 	long diff;
 	size_t			locations_size = 0, locations_pos = 0;
 
@@ -218,23 +278,22 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 	for (i = 0; i < sms->Number; i++) {
 		if (sms->SMS[i].PDU == SMS_Status_Report) {
 			strcpy(buffer2, DecodeUnicodeString(sms->SMS[i].Number));
-			SMSD_Log(0, Config, "Delivery report: %s to %s", DecodeUnicodeString(sms->SMS[i].  Text), buffer2);
+			SMSD_Log(DEBUG_INFO, Config, "Delivery report: %s to %s", DecodeUnicodeString(sms->SMS[i].  Text), buffer2);
 
-			sprintf(buffer,
+			if (SMSDPgSQL_Query(Config, &Res,
 				"SELECT ID, Status, EXTRACT(EPOCH FROM SendingDateTime), DeliveryDateTime, SMSCNumber "
                                         "FROM sentitems WHERE "
 					"DeliveryDateTime IS NULL AND "
 					"SenderID = '%s' AND TPMR = '%i' AND DestinationNumber = '%s'",
-				Config->PhoneID, sms->SMS[i].MessageReference, buffer2);
-			if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-				SMSD_Log(0, Config, "Error reading from database (%s)", __FUNCTION__);
-				return ERR_UNKNOWN;
+				Config->PhoneID, sms->SMS[i].MessageReference, buffer2) != ERR_NONE) {
+					SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
+					return ERR_UNKNOWN;
 			}
 
-			found = false;
+			found = FALSE;
 			numb_rows = PQntuples(Res);
 			for (j = 0; j < numb_rows; j++) {
-				SMSD_Log(4, Config, "Checking for delivery report, SMSC=%s, state=%s", PQgetvalue(Res, j, 4), PQgetvalue(Res, j, 1));
+				SMSD_Log(DEBUG_NOTICE, Config, "Checking for delivery report, SMSC=%s, state=%s", PQgetvalue(Res, j, 4), PQgetvalue(Res, j, 1));
 
 				if (strcmp
 				    (PQgetvalue(Res, j, 4),
@@ -256,10 +315,10 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 					diff = t_time2 - t_time1;
 
 					if (diff > -Config->deliveryreportdelay && diff < Config->deliveryreportdelay) {
-						found = true;
+						found = TRUE;
 						break;
 					} else {
-						SMSD_Log(1, Config, "Delivery report would match, but time delta is too big (%ld), consider increasing DeliveryReportDelay", diff);
+						SMSD_Log(DEBUG_NOTICE, Config, "Delivery report would match, but time delta is too big (%ld), consider increasing DeliveryReportDelay", diff);
 					}
 				}
 			}
@@ -297,8 +356,8 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 					" WHERE ID = '%s' AND TPMR = %i",
 					PQgetvalue(Res, j, 0),
 					sms->SMS[i].MessageReference);
-				if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-					SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
+				if (SMSDPgSQL_Query(Config, &Res, "%s", buffer) != ERR_NONE) {
+					SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 					return ERR_UNKNOWN;
 				}
 			}
@@ -382,13 +441,7 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 
 			case SMS_Coding_Default_No_Compression:
 				EncodeUTF8(buffer2, sms->SMS[i].Text);
-#ifdef HAVE_PQESCAPESTRINGCONN
-				PQescapeStringConn(Config->DBConnPgSQL, buffer4,
-						   buffer2, strlen(buffer2),
-						   NULL);
-#else
-				PQescapeString(buffer4, buffer2, strlen(buffer2));
-#endif
+				SMSDPgSQL_Escape(Config, buffer4, buffer2);
 				memcpy(buffer + strlen(buffer), buffer4,
 				       strlen(buffer4) + 1);
 				break;
@@ -401,8 +454,8 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 		}
 
 		sprintf(buffer + strlen(buffer), "','%s')", Config->PhoneID);
-		if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
+		if (SMSDPgSQL_Query(Config, &Res, "%s", buffer) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		PQclear(Res);
@@ -416,16 +469,15 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 			}
 		}
 
-		if (SMSDPgSQL_Query(Config, "SELECT currval('inbox_id_seq')", &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error getting current ID (%s)", __FUNCTION__);
+		if (SMSDPgSQL_Query(Config, &Res, "%s", "SELECT currval('inbox_id_seq')") != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error getting current ID (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		locations_pos += sprintf((*Locations) + locations_pos, "%s ", PQgetvalue(Res, 0, 0));
 		PQclear(Res);
 
-		sprintf(buffer, "UPDATE phones SET Received = Received + 1 WHERE IMEI = '%s'", Config->Status->IMEI);
-		if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error updating number of received messages (%s)", __FUNCTION__);
+		if (SMSDPgSQL_Query(Config, &Res, "UPDATE phones SET Received = Received + 1 WHERE IMEI = '%s'", Config->Status->IMEI) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error updating number of received messages (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		PQclear(Res);
@@ -438,15 +490,12 @@ static GSM_Error SMSDPgSQL_SaveInboxSMS(GSM_MultiSMSMessage *sms,
 static GSM_Error SMSDPgSQL_RefreshSendStatus(GSM_SMSDConfig * Config,
 					     char *ID)
 {
-	unsigned char buffer[10000];
 	PGresult *Res;
 
-	sprintf(buffer, "UPDATE outbox SET SendingTimeOut = now() + INTERVAL '15 seconds' "
-                        "WHERE ID = '%s' AND SendingTimeOut < now()",
-		ID);
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+	if (SMSDPgSQL_Query(Config, &Res, "UPDATE outbox SET SendingTimeOut = now() + INTERVAL '15 seconds' "
+		"WHERE ID = '%s' AND (SendingTimeOut < now() OR SendingTimeOut IS NULL)", ID) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
+			return ERR_UNKNOWN;
 	}
 
 	if (atoi(PQcmdTuples(Res)) == 0) {
@@ -469,15 +518,12 @@ static GSM_Error SMSDPgSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms,
 	PGresult *Res;
 	int i, j;
 	int numb_rows;
-	bool found = false;
+	gboolean found = FALSE;
 
-	sprintf(buf,
-		"SELECT ID, InsertIntoDB, SendingDateTime, SenderID FROM outbox "
-                      "WHERE SendingDateTime < now() AND SendingTimeOut < now()");
-
-	if (SMSDPgSQL_Query(Config, buf, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error reading from database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+	if (SMSDPgSQL_Query(Config, &Res, "SELECT ID, InsertIntoDB, SendingDateTime, SenderID FROM outbox "
+		"WHERE SendingDateTime < now() AND SendingTimeOut < now()") != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
+			return ERR_UNKNOWN;
 	}
 
 	numb_rows = PQntuples(Res);
@@ -490,7 +536,7 @@ static GSM_Error SMSDPgSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms,
 		    || !strcmp(PQgetvalue(Res, j, 3), Config->PhoneID)) {
 
 			if (SMSDPgSQL_RefreshSendStatus(Config, ID) == ERR_NONE) {
-				found = true;
+				found = TRUE;
 				break;
 			}
 		}
@@ -521,8 +567,8 @@ static GSM_Error SMSDPgSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms,
 				"FROM outbox_multipart WHERE ID='%s' AND SequencePosition='%i'",
 				ID, i);
 		}
-		if (SMSDPgSQL_Query(Config, buf, &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error reading from database (%s)", __FUNCTION__);
+		if (SMSDPgSQL_Query(Config, &Res, "%s", buf) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 
@@ -544,7 +590,7 @@ static GSM_Error SMSDPgSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms,
 
 		if (PQgetvalue(Res, 0, 0) == NULL
 		    || strlen(PQgetvalue(Res, 0, 0)) == 0) {
-			SMSD_Log(1, Config, "Message: %s", PQgetvalue(Res, 0, 4));
+			SMSD_Log(DEBUG_NOTICE, Config, "Message: %s", PQgetvalue(Res, 0, 4));
 			DecodeUTF8(sms->SMS[sms->Number].Text,
 				   PQgetvalue(Res, 0, 4),
 				   strlen(PQgetvalue(Res, 0, 4)));
@@ -623,21 +669,18 @@ static GSM_Error SMSDPgSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms,
 /* After sending SMS is moved to Sent Items or Error Items. */
 static GSM_Error SMSDPgSQL_MoveSMS(GSM_MultiSMSMessage * sms UNUSED,
 				   GSM_SMSDConfig * Config, char *ID,
-				   bool alwaysDelete UNUSED, bool sent UNUSED)
+				   gboolean alwaysDelete UNUSED, gboolean sent UNUSED)
 {
-	unsigned char buffer[10000];
 	PGresult *Res;
 
-	sprintf(buffer, "DELETE FROM outbox WHERE ID = '%s'", ID);
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s)", __FUNCTION__);
+	if (SMSDPgSQL_Query(Config, &Res, "DELETE FROM outbox WHERE ID = '%s'", ID) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	PQclear(Res);
 
-	sprintf(buffer, "DELETE FROM outbox_multipart WHERE ID = '%s'", ID);
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error deleting from database (%s)", __FUNCTION__);
+	if (SMSDPgSQL_Query(Config, &Res, "DELETE FROM outbox_multipart WHERE ID = '%s'", ID) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	PQclear(Res);
@@ -647,7 +690,7 @@ static GSM_Error SMSDPgSQL_MoveSMS(GSM_MultiSMSMessage * sms UNUSED,
 
 /* Adds SMS to Outbox */
 static GSM_Error SMSDPgSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms,
-					   GSM_SMSDConfig * Config)
+					   GSM_SMSDConfig * Config, char *NewID)
 {
 	unsigned char buffer[10000], buffer2[400], buffer5[400];
 	int i, ID = 0;
@@ -689,9 +732,9 @@ static GSM_Error SMSDPgSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms,
 			}
 
 			if (sms->Number == 1) {
-				sprintf(buffer + strlen(buffer), "false");
+				sprintf(buffer + strlen(buffer), "FALSE");
 			} else {
-				sprintf(buffer + strlen(buffer), "true");
+				sprintf(buffer + strlen(buffer), "TRUE");
 			}
 
 			sprintf(buffer + strlen(buffer), "', now()");
@@ -774,13 +817,7 @@ static GSM_Error SMSDPgSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms,
 
 			case SMS_Coding_Default_No_Compression:
 				EncodeUTF8(buffer2, sms->SMS[i].Text);
-#ifdef HAVE_PQESCAPESTRINGCONN
-				PQescapeStringConn(Config->DBConnPgSQL, buffer5,
-						   buffer2, strlen(buffer2),
-						   NULL);
-#else
-				PQescapeString(buffer5, buffer2, strlen(buffer2));
-#endif
+				SMSDPgSQL_Escape(Config, buffer5, buffer2);
 				memcpy(buffer + strlen(buffer), buffer5,
 				       strlen(buffer5) + 1);
 				break;
@@ -796,28 +833,29 @@ static GSM_Error SMSDPgSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms,
 		}
 		strcat(buffer, ")");
 
-		if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-			SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
+		if (SMSDPgSQL_Query(Config, &Res, "%s", buffer) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
 		PQclear(Res);
 
 		if (i == 0) {
-			if (SMSDPgSQL_Query(Config, "SELECT currval('outbox_id_seq')", &Res) != ERR_NONE) {
-				SMSD_Log(0, Config, "Error getting current ID (%s)", __FUNCTION__);
+			if (SMSDPgSQL_Query(Config, &Res, "%s", "SELECT currval('outbox_id_seq')") != ERR_NONE) {
+				SMSD_Log(DEBUG_INFO, Config, "Error getting current ID (%s)", __FUNCTION__);
 				return ERR_UNKNOWN;
 			}
 			ID = atoi(PQgetvalue(Res, 0, 0));
 			PQclear(Res);
 
 			if (ID == 0) {
-				SMSD_Log(0, Config, "Failed to get inserted row ID (%s)", __FUNCTION__);
+				SMSD_Log(DEBUG_INFO, Config, "Failed to get inserted row ID (%s)", __FUNCTION__);
 				PQclear(Res);
 				return ERR_UNKNOWN;
 			}
 		}
 	}
-	SMSD_Log(0, Config, "Written message with ID %i", ID);
+	SMSD_Log(DEBUG_INFO, Config, "Written message with ID %i", ID);
+	if (NewID != NULL) sprintf(NewID, "%d", ID);
 	return ERR_NONE;
 }
 
@@ -831,7 +869,7 @@ static GSM_Error SMSDPgSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms,
 	unsigned char buffer[10000], buffer2[400], buff[50], buffer5[400];
 
 	if (err == SMSD_SEND_OK) {
-		SMSD_Log(1, Config, "Transmitted %s (%s: %i) to %s", Config->SMSID,
+		SMSD_Log(DEBUG_NOTICE, Config, "Transmitted %s (%s: %i) to %s", Config->SMSID,
 			     (Part == sms->Number ? "total" : "part"), Part,
 			     DecodeUnicodeString(sms->SMS[0].Number));
 	}
@@ -839,16 +877,16 @@ static GSM_Error SMSDPgSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms,
 	buff[0] = 0;
 	if (err == SMSD_SEND_OK) {
 		if (sms->SMS[Part - 1].PDU == SMS_Status_Report) {
-			sprintf(buff, "SendingOK");
+			snprintf(buff, sizeof(buff), "SendingOK");
 		} else {
-			sprintf(buff, "SendingOKNoReport");
+			snprintf(buff, sizeof(buff), "SendingOKNoReport");
 		}
 	}
 
 	if (err == SMSD_SEND_SENDING_ERROR)
-		sprintf(buff, "SendingError");
+		snprintf(buff, sizeof(buff), "SendingError");
 	if (err == SMSD_SEND_ERROR)
-		sprintf(buff, "Error");
+		snprintf(buff, sizeof(buff), "Error");
 
 	buffer[0] = 0;
 	sprintf(buffer + strlen(buffer), "INSERT INTO sentitems "
@@ -923,13 +961,7 @@ static GSM_Error SMSDPgSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms,
 
 		case SMS_Coding_Default_No_Compression:
 			EncodeUTF8(buffer2, sms->SMS[Part - 1].Text);
-#ifdef HAVE_PQESCAPESTRINGCONN
-			PQescapeStringConn(Config->DBConnPgSQL, buffer5,
-					   buffer2, strlen(buffer2),
-					   NULL);
-#else
-			PQescapeString(buffer5, buffer2, strlen(buffer2));
-#endif
+			SMSDPgSQL_Escape(Config, buffer5, buffer2);
 			memcpy(buffer + strlen(buffer), buffer5,
 			       strlen(buffer5) + 1);
 			break;
@@ -948,15 +980,14 @@ static GSM_Error SMSDPgSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms,
 		sprintf(buffer + strlen(buffer), "-1')");
 	}
 
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
+	if (SMSDPgSQL_Query(Config, &Res, "%s", buffer) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	PQclear(Res);
 
-	sprintf(buffer, "UPDATE phones SET Sent= Sent + 1 WHERE IMEI = '%s'", Config->Status->IMEI);
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
+	if (SMSDPgSQL_Query(Config, &Res, "UPDATE phones SET Sent= Sent + 1 WHERE IMEI = '%s'", Config->Status->IMEI) != ERR_NONE) {
+		SMSD_Log(DEBUG_INFO, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	PQclear(Res);
@@ -968,14 +999,10 @@ static GSM_Error SMSDPgSQL_RefreshPhoneStatus(GSM_SMSDConfig * Config)
 {
 	PGresult *Res;
 
-	unsigned char buffer[500];
-
-	sprintf(buffer,
-		"UPDATE phones SET TimeOut= now() + INTERVAL '10 seconds', Battery = %d, Signal = %d WHERE IMEI = '%s'",
-		Config->Status->Charge.BatteryPercent, Config->Status->Network.SignalPercent, Config->Status->IMEI);
-	if (SMSDPgSQL_Query(Config, buffer, &Res) != ERR_NONE) {
-		SMSD_Log(0, Config, "Error writing to database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
+	if (SMSDPgSQL_Query(Config, &Res, "UPDATE phones SET TimeOut= now() + INTERVAL '10 seconds', Battery = %d, Signal = %d WHERE IMEI = '%s'",
+		Config->Status->Charge.BatteryPercent, Config->Status->Network.SignalPercent, Config->Status->IMEI) != ERR_NONE) {
+			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
+			return ERR_UNKNOWN;
 	}
 	PQclear(Res);
 
