@@ -23,16 +23,19 @@ int main(int argc UNUSED, char **argv UNUSED)
 	GSM_StateMachine *s;
 	GSM_Error error;
 
+	/* Init locales to get proper encoding */
+	GSM_InitLocales(NULL);
+
 	/* Configure state machine */
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Allocates state machine */
 	s = GSM_AllocStateMachine();
 	test_result(s != NULL);
 	debug_info = GSM_GetDebug(s);
-	GSM_SetDebugGlobal(true, debug_info);
+	GSM_SetDebugGlobal(TRUE, debug_info);
 
 	/* Initialize AT engine */
 	Data = &s->Phone.Data;
@@ -129,6 +132,42 @@ int main(int argc UNUSED, char **argv UNUSED)
 			);
 	gammu_test_result(error, "+SPBR: @i, @p, @p, @p, @p, @p, @s, @t, @t, @t, @t");
 
+	error = ATGEN_ParseReply(s,
+				"+SPBR: 2,\"+79217962807\",\"+78125313912\",\"\",\"\",\"\",\"\",\"16,Абакумов\",\"18,Александр\",\"0,\",\"0,\"",
+				"+SPBR: @i, @p, @p, @p, @p, @p, @s, @T, @T, @T, @T",
+			&i,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE,
+			buffer, BUFFER_SIZE
+			);
+	gammu_test_result(error, "+SPBR: @i, @p, @p, @p, @p, @p, @s, @T, @T, @T, @T");
+
+	Priv->Charset = AT_CHARSET_UCS2;
+	Priv->Manufacturer = AT_Motorola;
+
+	error = ATGEN_ParseReply(s,
+		"+MPBR: 253,\"069912158732\",129,005700650067006C006500690074006E0065007200200053006100620069006E00650020004D0065006E00730061,3,0,255,0,1,1,255,255,0,,0,0,,,,,,,,\"\",\"\"",
+		"+MPBR: @i, @p, @i, @s, @i, @0",
+		&i,
+		buffer, BUFFER_SIZE,
+		&i,
+		buffer, BUFFER_SIZE,
+		&i);
+	gammu_test_result(error, "+MPBR: @i, @p, @i, @s, @i, @0");
+
+	error = ATGEN_ParseReply(s,
+		"+CPIN: SIM PIN",
+		"+CPIN: @r",
+		buffer, BUFFER_SIZE);
+	gammu_test_result(error, "+CPIN: @s");
+
 	/* Free state machine */
 	GSM_FreeStateMachine(s);
 
