@@ -11,7 +11,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
-#include <assert.h>
+
+#include "common.h"
 
 int main(int argc, char **argv)
 {
@@ -22,15 +23,15 @@ int main(int argc, char **argv)
 	char buffer[65536];
 	FILE *f;
 	size_t len;
-	bool generate = false;
+	gboolean generate = FALSE;
 	GSM_Backup backup;
 	int i;
 	GSM_Debug_Info *debug_info;
-	bool skipcal, skiptodo;
+	gboolean skipcal, skiptodo;
 
 	/* Configure debugging */
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Check parameters */
@@ -41,16 +42,16 @@ int main(int argc, char **argv)
 
 	/* Check for generating option */
 	if (argc == 4 && strcmp(argv[3], "generate") == 0) {
-		generate = true;
+		generate = TRUE;
 	}
 
 	/* Open file */
 	f = fopen(argv[1], "r");
-	assert(f != NULL);
+	test_result(f != NULL);
 
 	/* Read data */
 	len = fread(buffer, 1, sizeof(buffer) - 1, f);
-	assert(feof(f));
+	test_result(feof(f));
 
 	/* Zero terminate string */
 	buffer[len] = 0;
@@ -65,16 +66,13 @@ int main(int argc, char **argv)
 
 	/* Parse [iv]Calendar */
 	if (strstr(argv[1], ".ics") != NULL) {
-		error = GSM_DecodeVCALENDAR_VTODO(buffer, &pos, &cal, &todo,
+		error = GSM_DecodeVCALENDAR_VTODO(NULL, buffer, &pos, &cal, &todo,
 				Mozilla_iCalendar, Mozilla_VToDo);
 	} else {
-		error = GSM_DecodeVCALENDAR_VTODO(buffer, &pos, &cal, &todo,
+		error = GSM_DecodeVCALENDAR_VTODO(NULL, buffer, &pos, &cal, &todo,
 				SonyEricsson_VCalendar, SonyEricsson_VToDo);
 	}
-	if (error != ERR_NONE) {
-		printf("Parsing failed: %s\n", GSM_ErrorString(error));
-		return 1;
-	}
+	gammu_test_result(error, "GSM_DecodeVCALENDAR_VTODO");
 
 	/* Generate file if we should */
 	if (generate) {
@@ -92,27 +90,23 @@ int main(int argc, char **argv)
 		} else {
 			backup.ToDo[0] = NULL;
 		}
-		if (GSM_SaveBackupFile(argv[2], &backup, true) != ERR_NONE) {
-			printf("Error saving backup to %s\n", argv[2]);
-			return 1;
-		}
+		error = GSM_SaveBackupFile(argv[2], &backup, TRUE);
+		gammu_test_result(error, "GSM_SaveBackupFile");
 	}
 
 	/* Read file content */
 	GSM_ClearBackup(&backup);
-	if (GSM_ReadBackupFile(argv[2], &backup, GSM_Backup_GammuUCS2) != ERR_NONE) {
-		printf("Error reading backup from %s\n", argv[2]);
-		return 1;
-	}
+	error = GSM_ReadBackupFile(argv[2], &backup, GSM_Backup_GammuUCS2);
+	gammu_test_result(error, "GSM_ReadBackupFile");
 
 	/* Did we read something? */
-	skipcal = false;
+	skipcal = FALSE;
 	if (cal.EntriesNum == 0 && backup.Calendar[0] == NULL) {
-		skipcal = true;
+		skipcal = TRUE;
 	}
-	skiptodo = false;
+	skiptodo = FALSE;
 	if (todo.EntriesNum == 0 && backup.ToDo[0] == NULL) {
-		skiptodo = true;
+		skiptodo = TRUE;
 	}
 
 	/* Compare size */
@@ -128,6 +122,10 @@ int main(int argc, char **argv)
 	/* Compare content */
 	if (!skipcal) {
 		for (i = 0; i < cal.EntriesNum; i++) {
+			printf("%d %d\n", cal.Entries[i].EntryType,
+				backup.Calendar[0]->Entries[i].EntryType);
+			test_result(cal.Entries[i].EntryType ==
+				backup.Calendar[0]->Entries[i].EntryType);
 			switch (cal.Entries[i].EntryType) {
 				case CAL_TEXT:
 				case CAL_DESCRIPTION:
@@ -139,6 +137,8 @@ int main(int argc, char **argv)
 						backup.Calendar[0]->Entries[i].Text,
 						0)) {
 						printf("Calendar field %d is not the same!\n", i);
+						printf("vc: '%s'\n", DecodeUnicodeConsole(cal.Entries[i].Text));
+						printf("bak: '%s'\n", DecodeUnicodeConsole(backup.Calendar[0]->Entries[i].Text));
 						return 1;
 					}
 					break;
