@@ -5,7 +5,7 @@
 #include <stdio.h>
 #include <string.h>
 
-#include "../common/gsmphones.h"
+#include "../libgammu/gsmphones.h"
 
 
 int single_test(const char *string, const char* expected)
@@ -25,7 +25,8 @@ int main(int argc, char **argv)
 
 	rc |= single_test("247 01", "LMT LV");
 	rc |= single_test("24701", "LMT LV");
-	rc |= single_test("99999", "unknown");
+	rc |= single_test("99999", "GammuTel");
+	rc |= single_test("00000", "unknown");
 
 	return rc;
 }
