@@ -3,10 +3,13 @@
 #include <gammu.h>
 #include <stdlib.h>
 #include <stdio.h>
-#include "../common/protocol/protocol.h" /* Needed for GSM_Protocol_Message */
-#include "../common/gsmstate.h" /* Needed for state machine internals */
+#include <string.h>
+#include "../libgammu/protocol/protocol.h" /* Needed for GSM_Protocol_Message */
+#include "../libgammu/gsmstate.h" /* Needed for state machine internals */
 
-#include "sms-printing.h"
+#include "../helper/message-display.h"
+
+#include "common.h"
 
 unsigned char data[] = {
 	0x00, 0x02, 0x00, 0x01, 0x00, 0x00, 0x00, 0x71, 0x00, 0x00, 0x02, 0x48, 0x00, 0x00, 0x00, 0x00,
@@ -60,18 +63,16 @@ int main(int argc UNUSED, char **argv UNUSED)
 	GSM_MultiSMSMessage sms;
 
 	debug_info = GSM_GetGlobalDebug();
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Allocates state machine */
 	s = GSM_AllocStateMachine();
-	if (s == NULL) {
-		printf("Could not allocate state machine!\n");
-		return 1;
-	}
+	test_result (s != NULL);
+
 	debug_info = GSM_GetDebug(s);
-	GSM_SetDebugGlobal(true, debug_info);
-	GSM_SetDebugFileDescriptor(stderr, false, debug_info);
+	GSM_SetDebugGlobal(TRUE, debug_info);
+	GSM_SetDebugFileDescriptor(stderr, FALSE, debug_info);
 	GSM_SetDebugLevel("textall", debug_info);
 
 	/* Init file */
@@ -86,21 +87,19 @@ int main(int argc UNUSED, char **argv UNUSED)
 	error = N6510_DecodeFilesystemSMS(s, &sms, &file, 0);
 
 	/* Check expected text */
-	if (strcmp("Vodafone Messenger. Para conectarte desde el Cliente PC tu ID de Messenger es: es02012053 y tu clave es: 36079.",
-				DecodeUnicodeConsole(sms.SMS[0].Text)) != 0) {
-		printf("Messages do not match!\n");
-		return 1;
-	}
+	test_result(strcmp("Vodafone Messenger. Para conectarte desde el Cliente PC tu ID de Messenger es: es02012053 y tu clave es: 36079.",
+				DecodeUnicodeConsole(sms.SMS[0].Text)) == 0);
 
 	/* Display message */
-	DisplayTestSMS(sms);
+	DisplayMultiSMSInfo(&sms, FALSE, TRUE, NULL, NULL);
+	DisplayMultiSMSInfo(&sms, TRUE, TRUE, NULL, NULL);
 
 	/* Free state machine */
 	GSM_FreeStateMachine(s);
 
-	printf("%s\n", GSM_ErrorString(error));
+	gammu_test_result(error, "N6510_DecodeFilesystemSMS");
 
-	return (error == ERR_NONE) ? 0 : 1;
+	return 0;
 }
 
 /* Editor configuration
